"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub, ctx, cluster_security_group_name: str, description: str, tags: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new Amazon Redshift security group. You use security groups to control access to non-VPC clusters.  For information about managing security groups, go to Amazon Redshift Cluster Security Groups in the Amazon Redshift Cluster Management Guide.

    Args:
        cluster_security_group_name(str): The name for the security group. Amazon Redshift stores the value as a lowercase string. Constraints:   Must contain no more than 255 alphanumeric characters or hyphens.   Must not be "Default".   Must be unique for all security groups that are created by your Amazon Web Services account.   Example: examplesecuritygroup .
        description(str): A description for the security group.
        tags(List, optional): A list of tag instances. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.cluster.security_group.init.create(
                ctx, cluster_security_group_name=value, description=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.cluster.security_group.init.create cluster_security_group_name=value, description=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="create_cluster_security_group",
        op_kwargs={
            "ClusterSecurityGroupName": cluster_security_group_name,
            "Description": description,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, cluster_security_group_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes an Amazon Redshift security group.  You cannot delete a security group that is associated with any clusters. You cannot delete the default security group.   For information about managing security groups, go to Amazon Redshift Cluster Security Groups in the Amazon Redshift Cluster Management Guide.

    Args:
        cluster_security_group_name(str): The name of the cluster security group to be deleted.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.cluster.security_group.init.delete(
                ctx, cluster_security_group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.cluster.security_group.init.delete cluster_security_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="delete_cluster_security_group",
        op_kwargs={"ClusterSecurityGroupName": cluster_security_group_name},
    )


async def describe_all(
    hub,
    ctx,
    cluster_security_group_name: str = None,
    max_records: int = None,
    marker: str = None,
    tag_keys: List = None,
    tag_values: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about Amazon Redshift security groups. If the name of a security group is specified, the response will contain only information about only that security group.  For information about managing security groups, go to Amazon Redshift Cluster Security Groups in the Amazon Redshift Cluster Management Guide. If you specify both tag keys and tag values in the same request, Amazon Redshift returns all security groups that match any combination of the specified keys and values. For example, if you have owner and environment for tag keys, and admin and test for tag values, all security groups that have any combination of those values are returned. If both tag keys and values are omitted from the request, security groups are returned regardless of whether they have tag keys or values associated with them.

    Args:
        cluster_security_group_name(str, optional): The name of a cluster security group for which you are requesting details. You can specify either the Marker parameter or a ClusterSecurityGroupName parameter, but not both.   Example: securitygroup1 . Defaults to None.
        max_records(int, optional): The maximum number of response records to return in each call. If the number of remaining response records exceeds the specified MaxRecords value, a value is returned in a marker field of the response. You can retrieve the next set of records by retrying the command with the returned marker value.  Default: 100  Constraints: minimum 20, maximum 100. Defaults to None.
        marker(str, optional): An optional parameter that specifies the starting point to return a set of response records. When the results of a DescribeClusterSecurityGroups request exceed the value specified in MaxRecords, Amazon Web Services returns a value in the Marker field of the response. You can retrieve the next set of response records by providing the returned marker value in the Marker parameter and retrying the request.  Constraints: You can specify either the ClusterSecurityGroupName parameter or the Marker parameter, but not both. . Defaults to None.
        tag_keys(List, optional): A tag key or keys for which you want to return all matching cluster security groups that are associated with the specified key or keys. For example, suppose that you have security groups that are tagged with keys called owner and environment. If you specify both of these tag keys in the request, Amazon Redshift returns a response with the security groups that have either or both of these tag keys associated with them. Defaults to None.
        tag_values(List, optional): A tag value or values for which you want to return all matching cluster security groups that are associated with the specified tag value or values. For example, suppose that you have security groups that are tagged with values called admin and test. If you specify both of these tag values in the request, Amazon Redshift returns a response with the security groups that have either or both of these tag values associated with them. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.cluster.security_group.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.cluster.security_group.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="describe_cluster_security_groups",
        op_kwargs={
            "ClusterSecurityGroupName": cluster_security_group_name,
            "MaxRecords": max_records,
            "Marker": marker,
            "TagKeys": tag_keys,
            "TagValues": tag_values,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(
    hub,
    ctx,
    approval_rule_template_name: str,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all repositories associated with the specified approval rule template.

    Args:
        approval_rule_template_name(str): The name of the approval rule template for which you want to list repositories that are associated with that template.
        next_token(str, optional): An enumeration token that, when provided in a request, returns the next batch of the results. Defaults to None.
        max_results(int, optional): A non-zero, non-negative integer used to limit the number of returned results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codecommit.repository.for_approval_rule_template.list(
                ctx, approval_rule_template_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codecommit.repository.for_approval_rule_template.list approval_rule_template_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codecommit",
        operation="list_repositories_for_approval_rule_template",
        op_kwargs={
            "approvalRuleTemplateName": approval_rule_template_name,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(
    hub, ctx, resource_collection_type: str, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

     Returns the number of open proactive insights, open reactive insights, and the Mean Time to Recover (MTTR) for all closed insights in resource collections in your account. You specify the type of AWS resources collection. The one type of AWS resource collection supported is AWS CloudFormation stacks. DevOps Guru can be configured to analyze only the AWS resources that are defined in the stacks. You can specify up to 500 AWS CloudFormation stacks.

    Args:
        resource_collection_type(str):  An AWS resource collection type. This type specifies how analyzed AWS resources are defined. The one type of AWS resource collection supported is AWS CloudFormation stacks. DevOps Guru can be configured to analyze only the AWS resources that are defined in the stacks. You can specify up to 500 AWS CloudFormation stacks. .
        next_token(str, optional): The pagination token to use to retrieve the next page of results for this operation. If this value is null, it retrieves the first page. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devop_guru.resource_collection.health.describe(
                ctx, resource_collection_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devop_guru.resource_collection.health.describe resource_collection_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devops-guru",
        operation="describe_resource_collection_health",
        op_kwargs={
            "ResourceCollectionType": resource_collection_type,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    number_of_connections: int,
    location: str,
    connections_bandwidth: str,
    lag_name: str,
    connection_id: str = None,
    tags: List = None,
    child_connection_tags: List = None,
    provider_name: str = None,
    request_mac_sec: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a link aggregation group (LAG) with the specified number of bundled physical dedicated connections between the customer network and a specific Direct Connect location. A LAG is a logical interface that uses the Link Aggregation Control Protocol (LACP) to aggregate multiple interfaces, enabling you to treat them as a single interface. All connections in a LAG must use the same bandwidth (either 1Gbps or 10Gbps) and must terminate at the same Direct Connect endpoint. You can have up to 10 dedicated connections per LAG. Regardless of this limit, if you request more connections for the LAG than Direct Connect can allocate on a single endpoint, no LAG is created. You can specify an existing physical dedicated connection or interconnect to include in the LAG (which counts towards the total number of connections). Doing so interrupts the current physical dedicated connection, and re-establishes them as a member of the LAG. The LAG will be created on the same Direct Connect endpoint to which the dedicated connection terminates. Any virtual interfaces associated with the dedicated connection are automatically disassociated and re-associated with the LAG. The connection ID does not change. If the account used to create a LAG is a registered Direct Connect Partner, the LAG is automatically enabled to host sub-connections. For a LAG owned by a partner, any associated virtual interfaces cannot be directly configured.

    Args:
        number_of_connections(int): The number of physical dedicated connections initially provisioned and bundled by the LAG.
        location(str): The location for the LAG.
        connections_bandwidth(str): The bandwidth of the individual physical dedicated connections bundled by the LAG. The possible values are 1Gbps and 10Gbps. .
        lag_name(str): The name of the LAG.
        connection_id(str, optional): The ID of an existing dedicated connection to migrate to the LAG. Defaults to None.
        tags(List, optional): The tags to associate with the LAG. Defaults to None.
        child_connection_tags(List, optional): The tags to associate with the automtically created LAGs. Defaults to None.
        provider_name(str, optional): The name of the service provider associated with the LAG. Defaults to None.
        request_mac_sec(bool, optional): Indicates whether the connection will support MAC Security (MACsec).  All connections in the LAG must be capable of supporting MAC Security (MACsec). For information about MAC Security (MACsec) prerequisties, see MACsec prerequisties in the Direct Connect User Guide. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.directconnect.lag.create(
                ctx,
                number_of_connections=value,
                location=value,
                connections_bandwidth=value,
                lag_name=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.directconnect.lag.create number_of_connections=value, location=value, connections_bandwidth=value, lag_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="directconnect",
        operation="create_lag",
        op_kwargs={
            "numberOfConnections": number_of_connections,
            "location": location,
            "connectionsBandwidth": connections_bandwidth,
            "lagName": lag_name,
            "connectionId": connection_id,
            "tags": tags,
            "childConnectionTags": child_connection_tags,
            "providerName": provider_name,
            "requestMACSec": request_mac_sec,
        },
    )


async def delete(hub, ctx, lag_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified link aggregation group (LAG). You cannot delete a LAG if it has active virtual interfaces or hosted connections.

    Args:
        lag_id(str): The ID of the LAG.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.directconnect.lag.delete(ctx, lag_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.directconnect.lag.delete lag_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="directconnect",
        operation="delete_lag",
        op_kwargs={"lagId": lag_id},
    )


async def update(
    hub,
    ctx,
    lag_id: str,
    lag_name: str = None,
    minimum_links: int = None,
    encryption_mode: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the attributes of the specified link aggregation group (LAG). You can update the following LAG attributes:   The name of the LAG.   The value for the minimum number of connections that must be operational for the LAG itself to be operational.    The LAG's MACsec encryption mode. Amazon Web Services assigns this value to each connection which is part of the LAG.   The tags    If you adjust the threshold value for the minimum number of operational connections, ensure that the new value does not cause the LAG to fall below the threshold and become non-operational.

    Args:
        lag_id(str): The ID of the LAG.
        lag_name(str, optional): The name of the LAG. Defaults to None.
        minimum_links(int, optional): The minimum number of physical connections that must be operational for the LAG itself to be operational. Defaults to None.
        encryption_mode(str, optional): The LAG MAC Security (MACsec) encryption mode. Amazon Web Services applies the value to all connections which are part of the LAG. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.directconnect.lag.update(ctx, lag_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.directconnect.lag.update lag_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="directconnect",
        operation="update_lag",
        op_kwargs={
            "lagId": lag_id,
            "lagName": lag_name,
            "minimumLinks": minimum_links,
            "encryptionMode": encryption_mode,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub,
    ctx,
    instance_id: str,
    filters: List = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about the patches on the specified instance and their state relative to the patch baseline being used for the instance.

    Args:
        instance_id(str): The ID of the instance whose patch state information should be retrieved.
        filters(List, optional): Each element in the array is a structure containing a key-value pair. Supported keys for DescribeInstancePatchesinclude the following:     Classification   Sample values: Security | SecurityUpdates      KBId   Sample values: KB4480056 | java-1.7.0-openjdk.x86_64      Severity   Sample values: Important | Medium | Low      State   Sample values: Installed | InstalledOther | InstalledPendingReboot   . Defaults to None.
        next_token(str, optional): The token for the next set of items to return. (You received this token from a previous call.). Defaults to None.
        max_results(int, optional): The maximum number of patches to return (per page). Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.instance.patch.init.describe_all(ctx, instance_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.instance.patch.init.describe_all instance_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="describe_instance_patches",
        op_kwargs={
            "InstanceId": instance_id,
            "Filters": filters,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub, ctx, channel_arn: str, member_arn: str, chime_bearer: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Permanently bans a member from a channel. Moderators can't add banned members to a channel. To undo a ban, you first have to DeleteChannelBan, and then CreateChannelMembership. Bans are cleaned up when you delete users or channels. If you ban a user who is already part of a channel, that user is automatically kicked from the channel.  The x-amz-chime-bearer request header is mandatory. Use the AppInstanceUserArn of the user that makes the API call as the value in the header.

    Args:
        channel_arn(str): The ARN of the ban request.
        member_arn(str): The ARN of the member being banned.
        chime_bearer(str, optional): The AppInstanceUserArn of the user that makes the API call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.channel.ban.create(
                ctx, channel_arn=value, member_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.channel.ban.create channel_arn=value, member_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="create_channel_ban",
        op_kwargs={
            "ChannelArn": channel_arn,
            "MemberArn": member_arn,
            "ChimeBearer": chime_bearer,
        },
    )


async def delete(
    hub, ctx, channel_arn: str, member_arn: str, chime_bearer: str = None
) -> None:
    r"""
    **Autogenerated function**

    Removes a user from a channel's ban list.  The x-amz-chime-bearer request header is mandatory. Use the AppInstanceUserArn of the user that makes the API call as the value in the header.

    Args:
        channel_arn(str): The ARN of the channel from which the AppInstanceUser was banned.
        member_arn(str): The ARN of the AppInstanceUser that you want to reinstate.
        chime_bearer(str, optional): The AppInstanceUserArn of the user that makes the API call. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.channel.ban.delete(
                ctx, channel_arn=value, member_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.channel.ban.delete channel_arn=value, member_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="delete_channel_ban",
        op_kwargs={
            "ChannelArn": channel_arn,
            "MemberArn": member_arn,
            "ChimeBearer": chime_bearer,
        },
    )


async def describe(
    hub, ctx, channel_arn: str, member_arn: str, chime_bearer: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns the full details of a channel ban.  The x-amz-chime-bearer request header is mandatory. Use the AppInstanceUserArn of the user that makes the API call as the value in the header.

    Args:
        channel_arn(str): The ARN of the channel from which the user is banned.
        member_arn(str): The ARN of the member being banned.
        chime_bearer(str, optional): The AppInstanceUserArn of the user that makes the API call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.channel.ban.describe(
                ctx, channel_arn=value, member_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.channel.ban.describe channel_arn=value, member_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="describe_channel_ban",
        op_kwargs={
            "ChannelArn": channel_arn,
            "MemberArn": member_arn,
            "ChimeBearer": chime_bearer,
        },
    )


async def list_all(
    hub,
    ctx,
    channel_arn: str,
    max_results: int = None,
    next_token: str = None,
    chime_bearer: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all the users banned from a particular channel.  The x-amz-chime-bearer request header is mandatory. Use the AppInstanceUserArn of the user that makes the API call as the value in the header.

    Args:
        channel_arn(str): The ARN of the channel.
        max_results(int, optional): The maximum number of bans that you want returned. Defaults to None.
        next_token(str, optional): The token passed by previous API calls until all requested bans are returned. Defaults to None.
        chime_bearer(str, optional): The AppInstanceUserArn of the user that makes the API call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.channel.ban.list_all(ctx, channel_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.channel.ban.list_all channel_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="list_channel_bans",
        op_kwargs={
            "ChannelArn": channel_arn,
            "MaxResults": max_results,
            "NextToken": next_token,
            "ChimeBearer": chime_bearer,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(
    hub, ctx, approval_rule_template_name: str, repository_names: List
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an association between an approval rule template and one or more specified repositories.

    Args:
        approval_rule_template_name(str): The name of the template you want to associate with one or more repositories.
        repository_names(List): The names of the repositories you want to associate with the template.  The length constraint limit is for each string in the array. The array itself can be empty. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codecommit.associate.approval_rule_template_with_repository.batch(
                ctx, approval_rule_template_name=value, repository_names=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codecommit.associate.approval_rule_template_with_repository.batch approval_rule_template_name=value, repository_names=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codecommit",
        operation="batch_associate_approval_rule_template_with_repositories",
        op_kwargs={
            "approvalRuleTemplateName": approval_rule_template_name,
            "repositoryNames": repository_names,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub,
    ctx,
    stream_name: str = None,
    stream_arn: str = None,
    playback_mode: str = None,
    display_fragment_timestamp: str = None,
    display_fragment_number: str = None,
    dash_fragment_selector: Dict = None,
    expires: int = None,
    max_manifest_fragment_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves an MPEG Dynamic Adaptive Streaming over HTTP (DASH) URL for the stream. You can then open the URL in a media player to view the stream contents. Both the StreamName and the StreamARN parameters are optional, but you must specify either the StreamName or the StreamARN when invoking this API operation. An Amazon Kinesis video stream has the following requirements for providing data through MPEG-DASH:   The media must contain h.264 or h.265 encoded video and, optionally, AAC or G.711 encoded audio. Specifically, the codec ID of track 1 should be V_MPEG/ISO/AVC (for h.264) or V_MPEGH/ISO/HEVC (for H.265). Optionally, the codec ID of track 2 should be A_AAC (for AAC) or A_MS/ACM (for G.711).   Data retention must be greater than 0.   The video track of each fragment must contain codec private data in the Advanced Video Coding (AVC) for H.264 format and HEVC for H.265 format. For more information, see MPEG-4 specification ISO/IEC 14496-15. For information about adapting stream data to a given format, see NAL Adaptation Flags.   The audio track (if present) of each fragment must contain codec private data in the AAC format (AAC specification ISO/IEC 13818-7) or the MS Wave format.   The following procedure shows how to use MPEG-DASH with Kinesis Video Streams:   Get an endpoint using GetDataEndpoint, specifying GET_DASH_STREAMING_SESSION_URL for the APIName parameter.   Retrieve the MPEG-DASH URL using GetDASHStreamingSessionURL. Kinesis Video Streams creates an MPEG-DASH streaming session to be used for accessing content in a stream using the MPEG-DASH protocol. GetDASHStreamingSessionURL returns an authenticated URL (that includes an encrypted session token) for the session's MPEG-DASH manifest (the root resource needed for streaming with MPEG-DASH).  Don't share or store this token where an unauthorized entity can access it. The token provides access to the content of the stream. Safeguard the token with the same measures that you use with your AWS credentials.  The media that is made available through the manifest consists only of the requested stream, time range, and format. No other media data (such as frames outside the requested window or alternate bitrates) is made available.   Provide the URL (containing the encrypted session token) for the MPEG-DASH manifest to a media player that supports the MPEG-DASH protocol. Kinesis Video Streams makes the initialization fragment and media fragments available through the manifest URL. The initialization fragment contains the codec private data for the stream, and other data needed to set up the video or audio decoder and renderer. The media fragments contain encoded video frames or encoded audio samples.   The media player receives the authenticated URL and requests stream metadata and media data normally. When the media player requests data, it calls the following actions:    GetDASHManifest: Retrieves an MPEG DASH manifest, which contains the metadata for the media that you want to playback.    GetMP4InitFragment: Retrieves the MP4 initialization fragment. The media player typically loads the initialization fragment before loading any media fragments. This fragment contains the "fytp" and "moov" MP4 atoms, and the child atoms that are needed to initialize the media player decoder. The initialization fragment does not correspond to a fragment in a Kinesis video stream. It contains only the codec private data for the stream and respective track, which the media player needs to decode the media frames.    GetMP4MediaFragment: Retrieves MP4 media fragments. These fragments contain the "moof" and "mdat" MP4 atoms and their child atoms, containing the encoded fragment's media frames and their timestamps.   After the first media fragment is made available in a streaming session, any fragments that don't contain the same codec private data cause an error to be returned when those different media fragments are loaded. Therefore, the codec private data should not change between fragments in a session. This also means that the session fails if the fragments in a stream change from having only video to having both audio and video.  Data retrieved with this action is billable. See Pricing for details.      For restrictions that apply to MPEG-DASH sessions, see Kinesis Video Streams Limits.  You can monitor the amount of data that the media player consumes by monitoring the GetMP4MediaFragment.OutgoingBytes Amazon CloudWatch metric. For information about using CloudWatch to monitor Kinesis Video Streams, see Monitoring Kinesis Video Streams. For pricing information, see Amazon Kinesis Video Streams Pricing and AWS Pricing. Charges for both HLS sessions and outgoing AWS data apply. For more information about HLS, see HTTP Live Streaming on the Apple Developer site.  If an error is thrown after invoking a Kinesis Video Streams archived media API, in addition to the HTTP status code and the response body, it includes the following pieces of information:     x-amz-ErrorType HTTP header – contains a more specific error type in addition to what the HTTP status code provides.     x-amz-RequestId HTTP header – if you want to report an issue to AWS, the support team can better diagnose the problem if given the Request Id.   Both the HTTP status code and the ErrorType header can be utilized to make programmatic decisions about whether errors are retry-able and under what conditions, as well as provide information on what actions the client programmer might need to take in order to successfully try again. For more information, see the Errors section at the bottom of this topic, as well as Common Errors.

    Args:
        stream_name(str, optional): The name of the stream for which to retrieve the MPEG-DASH manifest URL. You must specify either the StreamName or the StreamARN. Defaults to None.
        stream_arn(str, optional): The Amazon Resource Name (ARN) of the stream for which to retrieve the MPEG-DASH manifest URL. You must specify either the StreamName or the StreamARN. Defaults to None.
        playback_mode(str, optional): Whether to retrieve live, live replay, or archived, on-demand data. Features of the three types of sessions include the following:     LIVE : For sessions of this type, the MPEG-DASH manifest is continually updated with the latest fragments as they become available. We recommend that the media player retrieve a new manifest on a one-second interval. When this type of session is played in a media player, the user interface typically displays a "live" notification, with no scrubber control for choosing the position in the playback window to display.  In LIVE mode, the newest available fragments are included in an MPEG-DASH manifest, even if there is a gap between fragments (that is, if a fragment is missing). A gap like this might cause a media player to halt or cause a jump in playback. In this mode, fragments are not added to the MPEG-DASH manifest if they are older than the newest fragment in the playlist. If the missing fragment becomes available after a subsequent fragment is added to the manifest, the older fragment is not added, and the gap is not filled.      LIVE_REPLAY : For sessions of this type, the MPEG-DASH manifest is updated similarly to how it is updated for LIVE mode except that it starts by including fragments from a given start time. Instead of fragments being added as they are ingested, fragments are added as the duration of the next fragment elapses. For example, if the fragments in the session are two seconds long, then a new fragment is added to the manifest every two seconds. This mode is useful to be able to start playback from when an event is detected and continue live streaming media that has not yet been ingested as of the time of the session creation. This mode is also useful to stream previously archived media without being limited by the 1,000 fragment limit in the ON_DEMAND mode.      ON_DEMAND : For sessions of this type, the MPEG-DASH manifest contains all the fragments for the session, up to the number that is specified in MaxManifestFragmentResults. The manifest must be retrieved only once for each session. When this type of session is played in a media player, the user interface typically displays a scrubber control for choosing the position in the playback window to display.   In all playback modes, if FragmentSelectorType is PRODUCER_TIMESTAMP, and if there are multiple fragments with the same start timestamp, the fragment that has the larger fragment number (that is, the newer fragment) is included in the MPEG-DASH manifest. The other fragments are not included. Fragments that have different timestamps but have overlapping durations are still included in the MPEG-DASH manifest. This can lead to unexpected behavior in the media player. The default is LIVE. Defaults to None.
        display_fragment_timestamp(str, optional): Per the MPEG-DASH specification, the wall-clock time of fragments in the manifest file can be derived using attributes in the manifest itself. However, typically, MPEG-DASH compatible media players do not properly handle gaps in the media timeline. Kinesis Video Streams adjusts the media timeline in the manifest file to enable playback of media with discontinuities. Therefore, the wall-clock time derived from the manifest file may be inaccurate. If DisplayFragmentTimestamp is set to ALWAYS, the accurate fragment timestamp is added to each S element in the manifest file with the attribute name “kvs:ts”. A custom MPEG-DASH media player is necessary to leverage this custom attribute. The default value is NEVER. When DASHFragmentSelector is SERVER_TIMESTAMP, the timestamps will be the server start timestamps. Similarly, when DASHFragmentSelector is PRODUCER_TIMESTAMP, the timestamps will be the producer start timestamps. . Defaults to None.
        display_fragment_number(str, optional): Fragments are identified in the manifest file based on their sequence number in the session. If DisplayFragmentNumber is set to ALWAYS, the Kinesis Video Streams fragment number is added to each S element in the manifest file with the attribute name “kvs:fn”. These fragment numbers can be used for logging or for use with other APIs (e.g. GetMedia and GetMediaForFragmentList). A custom MPEG-DASH media player is necessary to leverage these this custom attribute. The default value is NEVER. Defaults to None.
        dash_fragment_selector(Dict, optional): The time range of the requested fragment and the source of the timestamps. This parameter is required if PlaybackMode is ON_DEMAND or LIVE_REPLAY. This parameter is optional if PlaybackMode is LIVE. If PlaybackMode is LIVE, the FragmentSelectorType can be set, but the TimestampRange should not be set. If PlaybackMode is ON_DEMAND or LIVE_REPLAY, both FragmentSelectorType and TimestampRange must be set. Defaults to None.
        expires(int, optional): The time in seconds until the requested session expires. This value can be between 300 (5 minutes) and 43200 (12 hours). When a session expires, no new calls to GetDashManifest, GetMP4InitFragment, or GetMP4MediaFragment can be made for that session. The default is 300 (5 minutes). Defaults to None.
        max_manifest_fragment_results(int, optional): The maximum number of fragments that are returned in the MPEG-DASH manifest. When the PlaybackMode is LIVE, the most recent fragments are returned up to this value. When the PlaybackMode is ON_DEMAND, the oldest fragments are returned, up to this maximum number. When there are a higher number of fragments available in a live MPEG-DASH manifest, video players often buffer content before starting playback. Increasing the buffer size increases the playback latency, but it decreases the likelihood that rebuffering will occur during playback. We recommend that a live MPEG-DASH manifest have a minimum of 3 fragments and a maximum of 10 fragments. The default is 5 fragments if PlaybackMode is LIVE or LIVE_REPLAY, and 1,000 if PlaybackMode is ON_DEMAND.  The maximum value of 1,000 fragments corresponds to more than 16 minutes of video on streams with 1-second fragments, and more than 2 1/2 hours of video on streams with 10-second fragments. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesis_video_archived_media.dash_streaming_session_url.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesis_video_archived_media.dash_streaming_session_url.get
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesis-video-archived-media",
        operation="get_dash_streaming_session_url",
        op_kwargs={
            "StreamName": stream_name,
            "StreamARN": stream_arn,
            "PlaybackMode": playback_mode,
            "DisplayFragmentTimestamp": display_fragment_timestamp,
            "DisplayFragmentNumber": display_fragment_number,
            "DASHFragmentSelector": dash_fragment_selector,
            "Expires": expires,
            "MaxManifestFragmentResults": max_manifest_fragment_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(hub, ctx, application_name: str, revisions: List) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about one or more application revisions. The maximum number of application revisions that can be returned is 25.

    Args:
        application_name(str): The name of an AWS CodeDeploy application about which to get revision information.
        revisions(List): An array of RevisionLocation objects that specify information to get about the application revisions, including type and location. The maximum number of RevisionLocation objects you can specify is 25.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codedeploy.get.application.revision.batch(
                ctx, application_name=value, revisions=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codedeploy.get.application.revision.batch application_name=value, revisions=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codedeploy",
        operation="batch_get_application_revisions",
        op_kwargs={"applicationName": application_name, "revisions": revisions},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import List


async def put_multiple(hub, ctx, dataset_arn: str, items: List) -> None:
    r"""
    **Autogenerated function**

    Adds one or more items to an Items dataset. For more information see Importing Items Incrementally.

    Args:
        dataset_arn(str): The Amazon Resource Name (ARN) of the Items dataset you are adding the item or items to.
        items(List): A list of item data.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.personalize_event.item.put_multiple(
                ctx, dataset_arn=value, items=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.personalize_event.item.put_multiple dataset_arn=value, items=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="personalize-events",
        operation="put_items",
        op_kwargs={"datasetArn": dataset_arn, "items": items},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def configure(hub, ctx, id_: str, egress_access_logs: Dict = None) -> Dict:
    r"""
    **Autogenerated function**

    Changes the packaging group's properities to configure log subscription

    Args:
        egress_access_logs(Dict, optional): Configure egress access logging. Defaults to None.
        id_(str): The ID of a MediaPackage VOD PackagingGroup resource.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediapackage_vod.logs.configure(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediapackage_vod.logs.configure id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediapackage-vod",
        operation="configure_logs",
        op_kwargs={"EgressAccessLogs": egress_access_logs, "Id": id_},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub, ctx, identity_id: str, logins: Dict = None, custom_role_arn: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns credentials for the provided identity ID. Any provided logins will be validated against supported login providers. If the token is for cognito-identity.amazonaws.com, it will be passed through to AWS Security Token Service with the appropriate role for the token. This is a public API. You do not need any credentials to call this API.

    Args:
        identity_id(str): A unique identifier in the format REGION:GUID.
        logins(Dict, optional): A set of optional name-value pairs that map provider names to provider tokens. The name-value pair will follow the syntax "provider_name": "provider_user_identifier". Logins should not be specified when trying to get credentials for an unauthenticated identity. The Logins parameter is required when using identities associated with external identity providers such as Facebook. For examples of Logins maps, see the code examples in the External Identity Providers section of the Amazon Cognito Developer Guide. Defaults to None.
        custom_role_arn(str, optional): The Amazon Resource Name (ARN) of the role to be assumed when multiple roles were received in the token from the identity provider. For example, a SAML-based identity provider. This parameter is optional for identity providers that do not support role customization. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_identity.credential_for_identity.get(
                ctx, identity_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_identity.credential_for_identity.get identity_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-identity",
        operation="get_credentials_for_identity",
        op_kwargs={
            "IdentityId": identity_id,
            "Logins": logins,
            "CustomRoleArn": custom_role_arn,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(hub, ctx, endpoint_details: List, tags: Dict = None) -> Dict:
    r"""
    **Autogenerated function**

    Creates a DataflowEndpoint group containing the specified list of DataflowEndpoint objects. The name field in each endpoint is used in your mission profile DataflowEndpointConfig to specify which endpoints to use during a contact. When a contact uses multiple DataflowEndpointConfig objects, each Config must match a DataflowEndpoint in the same group.

    Args:
        endpoint_details(List): Endpoint details of each endpoint in the dataflow endpoint group.
        tags(Dict, optional): Tags of a dataflow endpoint group. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.groundstation.dataflow_endpoint_group.create(
                ctx, endpoint_details=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.groundstation.dataflow_endpoint_group.create endpoint_details=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="groundstation",
        operation="create_dataflow_endpoint_group",
        op_kwargs={"endpointDetails": endpoint_details, "tags": tags},
    )


async def delete(hub, ctx, dataflow_endpoint_group_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a dataflow endpoint group.

    Args:
        dataflow_endpoint_group_id(str): UUID of a dataflow endpoint group.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.groundstation.dataflow_endpoint_group.delete(
                ctx, dataflow_endpoint_group_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.groundstation.dataflow_endpoint_group.delete dataflow_endpoint_group_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="groundstation",
        operation="delete_dataflow_endpoint_group",
        op_kwargs={"dataflowEndpointGroupId": dataflow_endpoint_group_id},
    )


async def get(hub, ctx, dataflow_endpoint_group_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns the dataflow endpoint group.

    Args:
        dataflow_endpoint_group_id(str): UUID of a dataflow endpoint group.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.groundstation.dataflow_endpoint_group.get(
                ctx, dataflow_endpoint_group_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.groundstation.dataflow_endpoint_group.get dataflow_endpoint_group_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="groundstation",
        operation="get_dataflow_endpoint_group",
        op_kwargs={"dataflowEndpointGroupId": dataflow_endpoint_group_id},
    )


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of DataflowEndpoint groups.

    Args:
        max_results(int, optional): Maximum number of dataflow endpoint groups returned. Defaults to None.
        next_token(str, optional): Next token returned in the request of a previous ListDataflowEndpointGroups call. Used to get the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.groundstation.dataflow_endpoint_group.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.groundstation.dataflow_endpoint_group.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="groundstation",
        operation="list_dataflow_endpoint_groups",
        op_kwargs={"maxResults": max_results, "nextToken": next_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__virtualname__ = "id"


async def list_all(
    hub,
    ctx,
    secret_id: str,
    max_results: int = None,
    next_token: str = None,
    include_deprecated: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all of the versions attached to the specified secret. The output does not include the SecretString or SecretBinary fields. By default, the list includes only versions that have at least one staging label in VersionStage attached.  Always check the NextToken response parameter when calling any of the List* operations. These operations can occasionally return an empty or shorter than expected list of results even when there more results become available. When this happens, the NextToken response parameter contains a value to pass to the next call to the same API to request the next part of the list.   Minimum permissions  To run this command, you must have the following permissions:   secretsmanager:ListSecretVersionIds    Related operations    To list the secrets in an account, use ListSecrets.

    Args:
        secret_id(str): The identifier for the secret containing the versions you want to list. You can specify either the Amazon Resource Name (ARN) or the friendly name of the secret.  If you specify an ARN, we generally recommend that you specify a complete ARN. You can specify a partial ARN too—for example, if you don’t include the final hyphen and six random characters that Secrets Manager adds at the end of the ARN when you created the secret. A partial ARN match can work as long as it uniquely matches only one secret. However, if your secret has a name that ends in a hyphen followed by six characters (before Secrets Manager adds the hyphen and six characters to the ARN) and you try to use that as a partial ARN, then those characters cause Secrets Manager to assume that you’re specifying a complete ARN. This confusion can cause unexpected results. To avoid this situation, we recommend that you don’t create secret names ending with a hyphen followed by six characters. If you specify an incomplete ARN without the random suffix, and instead provide the 'friendly name', you must not include the random suffix. If you do include the random suffix added by Secrets Manager, you receive either a ResourceNotFoundException or an AccessDeniedException error, depending on your permissions. .
        max_results(int, optional): (Optional) Limits the number of results you want to include in the response. If you don't include this parameter, it defaults to a value that's specific to the operation. If additional items exist beyond the maximum you specify, the NextToken response element is present and has a value (isn't null). Include that value as the NextToken request parameter in the next call to the operation to get the next part of the results. Note that Secrets Manager might return fewer results than the maximum even when there are more results available. You should check NextToken after every operation to ensure that you receive all of the results. Defaults to None.
        next_token(str, optional): (Optional) Use this parameter in a request if you receive a NextToken response in a previous request indicating there's more output available. In a subsequent call, set it to the value of the previous call NextToken response to indicate where the output should continue from. Defaults to None.
        include_deprecated(bool, optional): (Optional) Specifies that you want the results to include versions that do not have any staging labels attached to them. Such versions are considered deprecated and are subject to deletion by Secrets Manager as needed. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.secretsmanager.secret.version.id_.list_all(ctx, secret_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.secretsmanager.secret.version.id.list_all secret_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="secretsmanager",
        operation="list_secret_version_ids",
        op_kwargs={
            "SecretId": secret_id,
            "MaxResults": max_results,
            "NextToken": next_token,
            "IncludeDeprecated": include_deprecated,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get_all(
    hub, ctx, filter_: List = None, max_items: int = None, marker: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about all IAM users, groups, roles, and policies in your Amazon Web Services account, including their relationships to one another. Use this operation to obtain a snapshot of the configuration of IAM permissions (users, groups, roles, and policies) in your account.  Policies returned by this operation are URL-encoded compliant with RFC 3986. You can use a URL decoding method to convert the policy back to plain JSON text. For example, if you use Java, you can use the decode method of the java.net.URLDecoder utility class in the Java SDK. Other languages and SDKs provide similar functionality.  You can optionally filter the results using the Filter parameter. You can paginate the results using the MaxItems and Marker parameters.

    Args:
        filter_(List, optional): A list of entity types used to filter the results. Only the entities that match the types you specify are included in the output. Use the value LocalManagedPolicy to include customer managed policies. The format for this parameter is a comma-separated (if more than one) list of strings. Each string value in the list must be one of the valid values listed below. Defaults to None.
        max_items(int, optional): Use this only when paginating results to indicate the maximum number of items you want in the response. If additional items exist beyond the maximum you specify, the IsTruncated response element is true. If you do not include this parameter, the number of items defaults to 100. Note that IAM might return fewer results, even when there are more results available. In that case, the IsTruncated response element returns true, and Marker contains a value to include in the subsequent call that tells the service where to continue from. Defaults to None.
        marker(str, optional): Use this parameter only when paginating results and only after you receive a response indicating that the results are truncated. Set it to the value of the Marker element in the response that you received to indicate where the next call should start. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.account.authorization_detail.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.account.authorization_detail.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="get_account_authorization_details",
        op_kwargs={"Filter": filter_, "MaxItems": max_items, "Marker": marker},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def assign(
    hub, ctx, tape_arn: str, pool_id: str, bypass_governance_retention: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Assigns a tape to a tape pool for archiving. The tape assigned to a pool is archived in the S3 storage class that is associated with the pool. When you use your backup application to eject the tape, the tape is archived directly into the S3 storage class (S3 Glacier or S3 Glacier Deep Archive) that corresponds to the pool. Valid Values: GLACIER | DEEP_ARCHIVE

    Args:
        tape_arn(str): The unique Amazon Resource Name (ARN) of the virtual tape that you want to add to the tape pool.
        pool_id(str): The ID of the pool that you want to add your tape to for archiving. The tape in this pool is archived in the S3 storage class that is associated with the pool. When you use your backup application to eject the tape, the tape is archived directly into the storage class (S3 Glacier or S3 Glacier Deep Archive) that corresponds to the pool. Valid Values: GLACIER | DEEP_ARCHIVE .
        bypass_governance_retention(bool, optional): Set permissions to bypass governance retention. If the lock type of the archived tape is Governance, the tape's archived age is not older than RetentionLockInDays, and the user does not already have BypassGovernanceRetention, setting this to TRUE enables the user to bypass the retention lock. This parameter is set to true by default for calls from the console. Valid values: TRUE | FALSE . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.storagegateway.tape.pool.assign(
                ctx, tape_arn=value, pool_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.storagegateway.tape.pool.assign tape_arn=value, pool_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="storagegateway",
        operation="assign_tape_pool",
        op_kwargs={
            "TapeARN": tape_arn,
            "PoolId": pool_id,
            "BypassGovernanceRetention": bypass_governance_retention,
        },
    )


async def create(
    hub,
    ctx,
    pool_name: str,
    storage_class: str,
    retention_lock_type: str = None,
    retention_lock_time_in_days: int = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new custom tape pool. You can use custom tape pool to enable tape retention lock on tapes that are archived in the custom pool.

    Args:
        pool_name(str): The name of the new custom tape pool.
        storage_class(str): The storage class that is associated with the new custom pool. When you use your backup application to eject the tape, the tape is archived directly into the storage class (S3 Glacier or S3 Glacier Deep Archive) that corresponds to the pool.
        retention_lock_type(str, optional): Tape retention lock can be configured in two modes. When configured in governance mode, accounts with specific IAM permissions are authorized to remove the tape retention lock from archived virtual tapes. When configured in compliance mode, the tape retention lock cannot be removed by any user, including the root account. Defaults to None.
        retention_lock_time_in_days(int, optional): Tape retention lock time is set in days. Tape retention lock can be enabled for up to 100 years (36,500 days). Defaults to None.
        tags(List, optional): A list of up to 50 tags that can be assigned to tape pool. Each tag is a key-value pair.  Valid characters for key and value are letters, spaces, and numbers representable in UTF-8 format, and the following special characters: + - = . _ : / @. The maximum length of a tag's key is 128 characters, and the maximum length for a tag's value is 256. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.storagegateway.tape.pool.create(
                ctx, pool_name=value, storage_class=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.storagegateway.tape.pool.create pool_name=value, storage_class=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="storagegateway",
        operation="create_tape_pool",
        op_kwargs={
            "PoolName": pool_name,
            "StorageClass": storage_class,
            "RetentionLockType": retention_lock_type,
            "RetentionLockTimeInDays": retention_lock_time_in_days,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, pool_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Delete a custom tape pool. A custom tape pool can only be deleted if there are no tapes in the pool and if there are no automatic tape creation policies that reference the custom tape pool.

    Args:
        pool_arn(str): The Amazon Resource Name (ARN) of the custom tape pool to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.storagegateway.tape.pool.delete(ctx, pool_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.storagegateway.tape.pool.delete pool_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="storagegateway",
        operation="delete_tape_pool",
        op_kwargs={"PoolARN": pool_arn},
    )


async def list_all(
    hub, ctx, pool_ar_ns: List = None, marker: str = None, limit: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists custom tape pools. You specify custom tape pools to list by specifying one or more custom tape pool Amazon Resource Names (ARNs). If you don't specify a custom tape pool ARN, the operation lists all custom tape pools. This operation supports pagination. You can optionally specify the Limit parameter in the body to limit the number of tape pools in the response. If the number of tape pools returned in the response is truncated, the response includes a Marker element that you can use in your subsequent request to retrieve the next set of tape pools.

    Args:
        pool_ar_ns(List, optional): The Amazon Resource Name (ARN) of each of the custom tape pools you want to list. If you don't specify a custom tape pool ARN, the response lists all custom tape pools. . Defaults to None.
        marker(str, optional): A string that indicates the position at which to begin the returned list of tape pools. Defaults to None.
        limit(int, optional): An optional number limit for the tape pools in the list returned by this call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.storagegateway.tape.pool.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.storagegateway.tape.pool.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="storagegateway",
        operation="list_tape_pools",
        op_kwargs={"PoolARNs": pool_ar_ns, "Marker": marker, "Limit": limit},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def subscribe(
    hub, ctx, identity_pool_id: str, identity_id: str, dataset_name: str, device_id: str
) -> Dict:
    r"""
    **Autogenerated function**

    Subscribes to receive notifications when a dataset is modified by another device.This API can only be called with temporary credentials provided by Cognito Identity. You cannot call this API with developer credentials.

    Args:
        identity_pool_id(str): A name-spaced GUID (for example, us-east-1:23EC4050-6AEA-7089-A2DD-08002EXAMPLE) created by Amazon Cognito. The ID of the pool to which the identity belongs.
        identity_id(str): Unique ID for this identity.
        dataset_name(str): The name of the dataset to subcribe to.
        device_id(str): The unique ID generated for this device by Cognito.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_sync.to_dataset.subscribe(
                ctx, identity_pool_id=value, identity_id=value, dataset_name=value, device_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_sync.to_dataset.subscribe identity_pool_id=value, identity_id=value, dataset_name=value, device_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-sync",
        operation="subscribe_to_dataset",
        op_kwargs={
            "IdentityPoolId": identity_pool_id,
            "IdentityId": identity_id,
            "DatasetName": dataset_name,
            "DeviceId": device_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    client_request_token: str,
    name: str,
    framework: str,
    framework_version: str,
    voting_policy: Dict,
    member_configuration: Dict,
    description: str = None,
    framework_configuration: Dict = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new blockchain network using Amazon Managed Blockchain. Applies only to Hyperledger Fabric.

    Args:
        client_request_token(str): A unique, case-sensitive identifier that you provide to ensure the idempotency of the operation. An idempotent operation completes no more than one time. This identifier is required only if you make a service request directly using an HTTP client. It is generated automatically if you use an AWS SDK or the AWS CLI.
        name(str): The name of the network.
        description(str, optional): An optional description for the network. Defaults to None.
        framework(str): The blockchain framework that the network uses.
        framework_version(str): The version of the blockchain framework that the network uses.
        framework_configuration(Dict, optional):  Configuration properties of the blockchain framework relevant to the network configuration. . Defaults to None.
        voting_policy(Dict):  The voting rules used by the network to determine if a proposal is approved. .
        member_configuration(Dict): Configuration properties for the first member within the network.
        tags(Dict, optional): Tags to assign to the network. Each tag consists of a key and optional value. When specifying tags during creation, you can specify multiple key-value pairs in a single request, with an overall maximum of 50 tags added to each resource. For more information about tags, see Tagging Resources in the Amazon Managed Blockchain Ethereum Developer Guide, or Tagging Resources in the Amazon Managed Blockchain Hyperledger Fabric Developer Guide. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.managedblockchain.network.create(
                ctx,
                client_request_token=value,
                name=value,
                framework=value,
                framework_version=value,
                voting_policy=value,
                member_configuration=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.managedblockchain.network.create client_request_token=value, name=value, framework=value, framework_version=value, voting_policy=value, member_configuration=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="managedblockchain",
        operation="create_network",
        op_kwargs={
            "ClientRequestToken": client_request_token,
            "Name": name,
            "Description": description,
            "Framework": framework,
            "FrameworkVersion": framework_version,
            "FrameworkConfiguration": framework_configuration,
            "VotingPolicy": voting_policy,
            "MemberConfiguration": member_configuration,
            "Tags": tags,
        },
    )


async def get(hub, ctx, network_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns detailed information about a network. Applies to Hyperledger Fabric and Ethereum.

    Args:
        network_id(str): The unique identifier of the network to get information about.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.managedblockchain.network.get(ctx, network_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.managedblockchain.network.get network_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="managedblockchain",
        operation="get_network",
        op_kwargs={"NetworkId": network_id},
    )


async def list_all(
    hub,
    ctx,
    name: str = None,
    framework: str = None,
    status: str = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about the networks in which the current AWS account participates. Applies to Hyperledger Fabric and Ethereum.

    Args:
        name(str, optional): The name of the network. Defaults to None.
        framework(str, optional): An optional framework specifier. If provided, only networks of this framework type are listed. Defaults to None.
        status(str, optional): An optional status specifier. If provided, only networks currently in this status are listed. Applies only to Hyperledger Fabric. Defaults to None.
        max_results(int, optional): The maximum number of networks to list. Defaults to None.
        next_token(str, optional): The pagination token that indicates the next set of results to retrieve. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.managedblockchain.network.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.managedblockchain.network.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="managedblockchain",
        operation="list_networks",
        op_kwargs={
            "Name": name,
            "Framework": framework,
            "Status": status,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__virtualname__ = "for_qualification_type"


__func_alias__ = {"list_": "list"}


async def list_(
    hub,
    ctx,
    qualification_type_id: str,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

     The ListHITsForQualificationType operation returns the HITs that use the given Qualification type for a Qualification requirement. The operation returns HITs of any status, except for HITs that have been deleted with the DeleteHIT operation or that have been auto-deleted.

    Args:
        qualification_type_id(str):  The ID of the Qualification type to use when querying HITs. .
        next_token(str, optional): Pagination Token. Defaults to None.
        max_results(int, optional):  Limit the number of results returned. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mturk.hits.for_qualification_type_.list(
                ctx, qualification_type_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mturk.hits.for_qualification_type.list qualification_type_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mturk",
        operation="list_hits_for_qualification_type",
        op_kwargs={
            "QualificationTypeId": qualification_type_id,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__virtualname__ = "prefix_list"


async def describe_all(
    hub,
    ctx,
    dry_run: bool = None,
    filters: List = None,
    max_results: int = None,
    next_token: str = None,
    prefix_list_ids: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes available Amazon Web Services services in a prefix list format, which includes the prefix list name and prefix list ID of the service and the IP address range for the service. We recommend that you use DescribeManagedPrefixLists instead.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        filters(List, optional): One or more filters.    prefix-list-id: The ID of a prefix list.    prefix-list-name: The name of a prefix list.  . Defaults to None.
        max_results(int, optional): The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value. Defaults to None.
        next_token(str, optional): The token for the next page of results. Defaults to None.
        prefix_list_ids(List, optional): One or more prefix list IDs. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.prefix_list_.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.prefix_list.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_prefix_lists",
        op_kwargs={
            "DryRun": dry_run,
            "Filters": filters,
            "MaxResults": max_results,
            "NextToken": next_token,
            "PrefixListIds": prefix_list_ids,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    domain_id: str,
    user_profile_name: str,
    app_type: str,
    app_name: str,
    tags: List = None,
    resource_spec: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a running app for the specified UserProfile. Supported apps are JupyterServer and KernelGateway. This operation is automatically invoked by Amazon SageMaker Studio upon access to the associated Domain, and when new kernel configurations are selected by the user. A user may have multiple Apps active simultaneously.

    Args:
        domain_id(str): The domain ID.
        user_profile_name(str): The user profile name.
        app_type(str): The type of app. Supported apps are JupyterServer and KernelGateway. TensorBoard is not supported.
        app_name(str): The name of the app.
        tags(List, optional): Each tag consists of a key and an optional value. Tag keys must be unique per resource. Defaults to None.
        resource_spec(Dict, optional): The instance type and the Amazon Resource Name (ARN) of the SageMaker image created on the instance. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.app.init.create(
                ctx, domain_id=value, user_profile_name=value, app_type=value, app_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.app.init.create domain_id=value, user_profile_name=value, app_type=value, app_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="create_app",
        op_kwargs={
            "DomainId": domain_id,
            "UserProfileName": user_profile_name,
            "AppType": app_type,
            "AppName": app_name,
            "Tags": tags,
            "ResourceSpec": resource_spec,
        },
    )


async def delete(
    hub, ctx, domain_id: str, user_profile_name: str, app_type: str, app_name: str
) -> None:
    r"""
    **Autogenerated function**

    Used to stop and delete an app.

    Args:
        domain_id(str): The domain ID.
        user_profile_name(str): The user profile name.
        app_type(str): The type of app.
        app_name(str): The name of the app.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.app.init.delete(
                ctx, domain_id=value, user_profile_name=value, app_type=value, app_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.app.init.delete domain_id=value, user_profile_name=value, app_type=value, app_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="delete_app",
        op_kwargs={
            "DomainId": domain_id,
            "UserProfileName": user_profile_name,
            "AppType": app_type,
            "AppName": app_name,
        },
    )


async def describe(
    hub, ctx, domain_id: str, user_profile_name: str, app_type: str, app_name: str
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the app.

    Args:
        domain_id(str): The domain ID.
        user_profile_name(str): The user profile name.
        app_type(str): The type of app.
        app_name(str): The name of the app.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.app.init.describe(
                ctx, domain_id=value, user_profile_name=value, app_type=value, app_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.app.init.describe domain_id=value, user_profile_name=value, app_type=value, app_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="describe_app",
        op_kwargs={
            "DomainId": domain_id,
            "UserProfileName": user_profile_name,
            "AppType": app_type,
            "AppName": app_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    stack_id: str,
    type_: str,
    name: str,
    shortname: str,
    attributes: Dict = None,
    cloud_watch_logs_configuration: Dict = None,
    custom_instance_profile_arn: str = None,
    custom_json: str = None,
    custom_security_group_ids: List = None,
    packages: List = None,
    volume_configurations: List = None,
    enable_auto_healing: bool = None,
    auto_assign_elastic_ips: bool = None,
    auto_assign_public_ips: bool = None,
    custom_recipes: Dict = None,
    install_updates_on_boot: bool = None,
    use_ebs_optimized_instances: bool = None,
    lifecycle_event_configuration: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a layer. For more information, see How to Create a Layer.  You should use CreateLayer for noncustom layer types such as PHP App Server only if the stack does not have an existing layer of that type. A stack can have at most one instance of each noncustom layer; if you attempt to create a second instance, CreateLayer fails. A stack can have an arbitrary number of custom layers, so you can call CreateLayer as many times as you like for that layer type.   Required Permissions: To use this action, an IAM user must have a Manage permissions level for the stack, or an attached policy that explicitly grants permissions. For more information on user permissions, see Managing User Permissions.

    Args:
        stack_id(str): The layer stack ID.
        type_(str): The layer type. A stack cannot have more than one built-in layer of the same type. It can have any number of custom layers. Built-in layers are not available in Chef 12 stacks.
        name(str): The layer name, which is used by the console.
        shortname(str): For custom layers only, use this parameter to specify the layer's short name, which is used internally by AWS OpsWorks Stacks and by Chef recipes. The short name is also used as the name for the directory where your app files are installed. It can have a maximum of 200 characters, which are limited to the alphanumeric characters, '-', '_', and '.'. The built-in layers' short names are defined by AWS OpsWorks Stacks. For more information, see the Layer Reference.
        attributes(Dict, optional): One or more user-defined key-value pairs to be added to the stack attributes. To create a cluster layer, set the EcsClusterArn attribute to the cluster's ARN. Defaults to None.
        cloud_watch_logs_configuration(Dict, optional): Specifies CloudWatch Logs configuration options for the layer. For more information, see CloudWatchLogsLogStream. Defaults to None.
        custom_instance_profile_arn(str, optional): The ARN of an IAM profile to be used for the layer's EC2 instances. For more information about IAM ARNs, see Using Identifiers. Defaults to None.
        custom_json(str, optional): A JSON-formatted string containing custom stack configuration and deployment attributes to be installed on the layer's instances. For more information, see  Using Custom JSON. This feature is supported as of version 1.7.42 of the AWS CLI. . Defaults to None.
        custom_security_group_ids(List, optional): An array containing the layer custom security group IDs. Defaults to None.
        packages(List, optional): An array of Package objects that describes the layer packages. Defaults to None.
        volume_configurations(List, optional): A VolumeConfigurations object that describes the layer's Amazon EBS volumes. Defaults to None.
        enable_auto_healing(bool, optional): Whether to disable auto healing for the layer. Defaults to None.
        auto_assign_elastic_ips(bool, optional): Whether to automatically assign an Elastic IP address to the layer's instances. For more information, see How to Edit a Layer. Defaults to None.
        auto_assign_public_ips(bool, optional): For stacks that are running in a VPC, whether to automatically assign a public IP address to the layer's instances. For more information, see How to Edit a Layer. Defaults to None.
        custom_recipes(Dict, optional): A LayerCustomRecipes object that specifies the layer custom recipes. Defaults to None.
        install_updates_on_boot(bool, optional): Whether to install operating system and package updates when the instance boots. The default value is true. To control when updates are installed, set this value to false. You must then update your instances manually by using CreateDeployment to run the update_dependencies stack command or by manually running yum (Amazon Linux) or apt-get (Ubuntu) on the instances.   To ensure that your instances have the latest security updates, we strongly recommend using the default value of true. . Defaults to None.
        use_ebs_optimized_instances(bool, optional): Whether to use Amazon EBS-optimized instances. Defaults to None.
        lifecycle_event_configuration(Dict, optional): A LifeCycleEventConfiguration object that you can use to configure the Shutdown event to specify an execution timeout and enable or disable Elastic Load Balancer connection draining. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opswork.layer.create(
                ctx, stack_id=value, type_=value, name=value, shortname=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opswork.layer.create stack_id=value, type_=value, name=value, shortname=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworks",
        operation="create_layer",
        op_kwargs={
            "StackId": stack_id,
            "Type": type_,
            "Name": name,
            "Shortname": shortname,
            "Attributes": attributes,
            "CloudWatchLogsConfiguration": cloud_watch_logs_configuration,
            "CustomInstanceProfileArn": custom_instance_profile_arn,
            "CustomJson": custom_json,
            "CustomSecurityGroupIds": custom_security_group_ids,
            "Packages": packages,
            "VolumeConfigurations": volume_configurations,
            "EnableAutoHealing": enable_auto_healing,
            "AutoAssignElasticIps": auto_assign_elastic_ips,
            "AutoAssignPublicIps": auto_assign_public_ips,
            "CustomRecipes": custom_recipes,
            "InstallUpdatesOnBoot": install_updates_on_boot,
            "UseEbsOptimizedInstances": use_ebs_optimized_instances,
            "LifecycleEventConfiguration": lifecycle_event_configuration,
        },
    )


async def delete(hub, ctx, layer_id: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a specified layer. You must first stop and then delete all associated instances or unassign registered instances. For more information, see How to Delete a Layer.  Required Permissions: To use this action, an IAM user must have a Manage permissions level for the stack, or an attached policy that explicitly grants permissions. For more information on user permissions, see Managing User Permissions.

    Args:
        layer_id(str): The layer ID.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opswork.layer.delete(ctx, layer_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opswork.layer.delete layer_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworks",
        operation="delete_layer",
        op_kwargs={"LayerId": layer_id},
    )


async def describe_all(hub, ctx, stack_id: str = None, layer_ids: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Requests a description of one or more layers in a specified stack.  This call accepts only one resource-identifying parameter.   Required Permissions: To use this action, an IAM user must have a Show, Deploy, or Manage permissions level for the stack, or an attached policy that explicitly grants permissions. For more information about user permissions, see Managing User Permissions.

    Args:
        stack_id(str, optional): The stack ID. Defaults to None.
        layer_ids(List, optional): An array of layer IDs that specify the layers to be described. If you omit this parameter, DescribeLayers returns a description of every layer in the specified stack. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opswork.layer.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opswork.layer.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworks",
        operation="describe_layers",
        op_kwargs={"StackId": stack_id, "LayerIds": layer_ids},
    )


async def update(
    hub,
    ctx,
    layer_id: str,
    name: str = None,
    shortname: str = None,
    attributes: Dict = None,
    cloud_watch_logs_configuration: Dict = None,
    custom_instance_profile_arn: str = None,
    custom_json: str = None,
    custom_security_group_ids: List = None,
    packages: List = None,
    volume_configurations: List = None,
    enable_auto_healing: bool = None,
    auto_assign_elastic_ips: bool = None,
    auto_assign_public_ips: bool = None,
    custom_recipes: Dict = None,
    install_updates_on_boot: bool = None,
    use_ebs_optimized_instances: bool = None,
    lifecycle_event_configuration: Dict = None,
) -> None:
    r"""
    **Autogenerated function**

    Updates a specified layer.  Required Permissions: To use this action, an IAM user must have a Manage permissions level for the stack, or an attached policy that explicitly grants permissions. For more information on user permissions, see Managing User Permissions.

    Args:
        layer_id(str): The layer ID.
        name(str, optional): The layer name, which is used by the console. Defaults to None.
        shortname(str, optional): For custom layers only, use this parameter to specify the layer's short name, which is used internally by AWS OpsWorks Stacks and by Chef. The short name is also used as the name for the directory where your app files are installed. It can have a maximum of 200 characters and must be in the following format: /\A[a-z0-9\-\_\.]+\Z/. The built-in layers' short names are defined by AWS OpsWorks Stacks. For more information, see the Layer Reference . Defaults to None.
        attributes(Dict, optional): One or more user-defined key/value pairs to be added to the stack attributes. Defaults to None.
        cloud_watch_logs_configuration(Dict, optional): Specifies CloudWatch Logs configuration options for the layer. For more information, see CloudWatchLogsLogStream. Defaults to None.
        custom_instance_profile_arn(str, optional): The ARN of an IAM profile to be used for all of the layer's EC2 instances. For more information about IAM ARNs, see Using Identifiers. Defaults to None.
        custom_json(str, optional): A JSON-formatted string containing custom stack configuration and deployment attributes to be installed on the layer's instances. For more information, see  Using Custom JSON. . Defaults to None.
        custom_security_group_ids(List, optional): An array containing the layer's custom security group IDs. Defaults to None.
        packages(List, optional): An array of Package objects that describe the layer's packages. Defaults to None.
        volume_configurations(List, optional): A VolumeConfigurations object that describes the layer's Amazon EBS volumes. Defaults to None.
        enable_auto_healing(bool, optional): Whether to disable auto healing for the layer. Defaults to None.
        auto_assign_elastic_ips(bool, optional): Whether to automatically assign an Elastic IP address to the layer's instances. For more information, see How to Edit a Layer. Defaults to None.
        auto_assign_public_ips(bool, optional): For stacks that are running in a VPC, whether to automatically assign a public IP address to the layer's instances. For more information, see How to Edit a Layer. Defaults to None.
        custom_recipes(Dict, optional): A LayerCustomRecipes object that specifies the layer's custom recipes. Defaults to None.
        install_updates_on_boot(bool, optional): Whether to install operating system and package updates when the instance boots. The default value is true. To control when updates are installed, set this value to false. You must then update your instances manually by using CreateDeployment to run the update_dependencies stack command or manually running yum (Amazon Linux) or apt-get (Ubuntu) on the instances.   We strongly recommend using the default value of true, to ensure that your instances have the latest security updates. . Defaults to None.
        use_ebs_optimized_instances(bool, optional): Whether to use Amazon EBS-optimized instances. Defaults to None.
        lifecycle_event_configuration(Dict, optional): . Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opswork.layer.update(ctx, layer_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opswork.layer.update layer_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworks",
        operation="update_layer",
        op_kwargs={
            "LayerId": layer_id,
            "Name": name,
            "Shortname": shortname,
            "Attributes": attributes,
            "CloudWatchLogsConfiguration": cloud_watch_logs_configuration,
            "CustomInstanceProfileArn": custom_instance_profile_arn,
            "CustomJson": custom_json,
            "CustomSecurityGroupIds": custom_security_group_ids,
            "Packages": packages,
            "VolumeConfigurations": volume_configurations,
            "EnableAutoHealing": enable_auto_healing,
            "AutoAssignElasticIps": auto_assign_elastic_ips,
            "AutoAssignPublicIps": auto_assign_public_ips,
            "CustomRecipes": custom_recipes,
            "InstallUpdatesOnBoot": install_updates_on_boot,
            "UseEbsOptimizedInstances": use_ebs_optimized_instances,
            "LifecycleEventConfiguration": lifecycle_event_configuration,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete_multiple(hub, ctx, schema_id: Dict, versions: str) -> Dict:
    r"""
    **Autogenerated function**

    Remove versions from the specified schema. A version number or range may be supplied. If the compatibility mode forbids deleting of a version that is necessary, such as BACKWARDS_FULL, an error is returned. Calling the GetSchemaVersions API after this call will list the status of the deleted versions. When the range of version numbers contain check pointed version, the API will return a 409 conflict and will not proceed with the deletion. You have to remove the checkpoint first using the DeleteSchemaCheckpoint API before using this API. You cannot use the DeleteSchemaVersions API to delete the first schema version in the schema set. The first schema version can only be deleted by the DeleteSchema API. This operation will also delete the attached SchemaVersionMetadata under the schema versions. Hard deletes will be enforced on the database. If the compatibility mode forbids deleting of a version that is necessary, such as BACKWARDS_FULL, an error is returned.

    Args:
        schema_id(Dict): This is a wrapper structure that may contain the schema name and Amazon Resource Name (ARN).
        versions(str): A version range may be supplied which may be of the format:   a single version number, 5   a range, 5-8 : deletes versions 5, 6, 7, 8  .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.schema.version.init.delete_multiple(
                ctx, schema_id=value, versions=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.schema.version.init.delete_multiple schema_id=value, versions=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="delete_schema_versions",
        op_kwargs={"SchemaId": schema_id, "Versions": versions},
    )


async def get(
    hub,
    ctx,
    schema_id: Dict = None,
    schema_version_id: str = None,
    schema_version_number: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Get the specified schema by its unique ID assigned when a version of the schema is created or registered. Schema versions in Deleted status will not be included in the results.

    Args:
        schema_id(Dict, optional): This is a wrapper structure to contain schema identity fields. The structure contains:   SchemaId$SchemaArn: The Amazon Resource Name (ARN) of the schema. Either SchemaArn or SchemaName and RegistryName has to be provided.   SchemaId$SchemaName: The name of the schema. Either SchemaArn or SchemaName and RegistryName has to be provided.  . Defaults to None.
        schema_version_id(str, optional): The SchemaVersionId of the schema version. This field is required for fetching by schema ID. Either this or the SchemaId wrapper has to be provided. Defaults to None.
        schema_version_number(Dict, optional): The version number of the schema. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.schema.version.init.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.schema.version.init.get
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="get_schema_version",
        op_kwargs={
            "SchemaId": schema_id,
            "SchemaVersionId": schema_version_id,
            "SchemaVersionNumber": schema_version_number,
        },
    )


async def list_all(
    hub, ctx, schema_id: Dict, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of schema versions that you have created, with minimal information. Schema versions in Deleted status will not be included in the results. Empty results will be returned if there are no schema versions available.

    Args:
        schema_id(Dict): This is a wrapper structure to contain schema identity fields. The structure contains:   SchemaId$SchemaArn: The Amazon Resource Name (ARN) of the schema. Either SchemaArn or SchemaName and RegistryName has to be provided.   SchemaId$SchemaName: The name of the schema. Either SchemaArn or SchemaName and RegistryName has to be provided.  .
        max_results(int, optional): Maximum number of results required per page. If the value is not supplied, this will be defaulted to 25 per page. Defaults to None.
        next_token(str, optional): A continuation token, if this is a continuation call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.schema.version.init.list_all(ctx, schema_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.schema.version.init.list_all schema_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="list_schema_versions",
        op_kwargs={
            "SchemaId": schema_id,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def register(hub, ctx, schema_id: Dict, schema_definition: str) -> Dict:
    r"""
    **Autogenerated function**

    Adds a new version to the existing schema. Returns an error if new version of schema does not meet the compatibility requirements of the schema set. This API will not create a new schema set and will return a 404 error if the schema set is not already present in the Schema Registry. If this is the first schema definition to be registered in the Schema Registry, this API will store the schema version and return immediately. Otherwise, this call has the potential to run longer than other operations due to compatibility modes. You can call the GetSchemaVersion API with the SchemaVersionId to check compatibility modes. If the same schema definition is already stored in Schema Registry as a version, the schema ID of the existing schema is returned to the caller.

    Args:
        schema_id(Dict): This is a wrapper structure to contain schema identity fields. The structure contains:   SchemaId$SchemaArn: The Amazon Resource Name (ARN) of the schema. Either SchemaArn or SchemaName and RegistryName has to be provided.   SchemaId$SchemaName: The name of the schema. Either SchemaArn or SchemaName and RegistryName has to be provided.  .
        schema_definition(str): The schema definition using the DataFormat setting for the SchemaName.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.schema.version.init.register(
                ctx, schema_id=value, schema_definition=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.schema.version.init.register schema_id=value, schema_definition=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="register_schema_version",
        op_kwargs={"SchemaId": schema_id, "SchemaDefinition": schema_definition},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import List


async def respond(
    hub, ctx, task_token: str, decisions: List = None, execution_context: str = None
) -> None:
    r"""
    **Autogenerated function**

    Used by deciders to tell the service that the DecisionTask identified by the taskToken has successfully completed. The decisions argument specifies the list of decisions made while processing the task. A DecisionTaskCompleted event is added to the workflow history. The executionContext specified is attached to the event in the workflow execution history.  Access Control  If an IAM policy grants permission to use RespondDecisionTaskCompleted, it can express permissions for the list of decisions in the decisions parameter. Each of the decisions has one or more parameters, much like a regular API call. To allow for policies to be as readable as possible, you can express permissions on decisions as if they were actual API calls, including applying conditions to some parameters. For more information, see Using IAM to Manage Access to Amazon SWF Workflows in the Amazon SWF Developer Guide.

    Args:
        task_token(str): The taskToken from the DecisionTask.   taskToken is generated by the service and should be treated as an opaque value. If the task is passed to another process, its taskToken must also be passed. This enables it to provide its progress and respond with results. .
        decisions(List, optional): The list of decisions (possibly empty) made by the decider while processing this decision task. See the docs for the Decision structure for details. Defaults to None.
        execution_context(str, optional): User defined context to add to workflow execution. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.swf.decision_task_completed.respond(ctx, task_token=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.swf.decision_task_completed.respond task_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="swf",
        operation="respond_decision_task_completed",
        op_kwargs={
            "taskToken": task_token,
            "decisions": decisions,
            "executionContext": execution_context,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    monitoring_schedule_name: str,
    monitoring_schedule_config: Dict,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a schedule that regularly starts Amazon SageMaker Processing Jobs to monitor the data captured for an Amazon SageMaker Endoint.

    Args:
        monitoring_schedule_name(str): The name of the monitoring schedule. The name must be unique within an Amazon Web Services Region within an Amazon Web Services account.
        monitoring_schedule_config(Dict): The configuration object that specifies the monitoring schedule and defines the monitoring job.
        tags(List, optional): (Optional) An array of key-value pairs. For more information, see Using Cost Allocation Tags in the Amazon Web Services Billing and Cost Management User Guide. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.monitoring.schedule.create(
                ctx, monitoring_schedule_name=value, monitoring_schedule_config=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.monitoring.schedule.create monitoring_schedule_name=value, monitoring_schedule_config=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="create_monitoring_schedule",
        op_kwargs={
            "MonitoringScheduleName": monitoring_schedule_name,
            "MonitoringScheduleConfig": monitoring_schedule_config,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, monitoring_schedule_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a monitoring schedule. Also stops the schedule had not already been stopped. This does not delete the job execution history of the monitoring schedule.

    Args:
        monitoring_schedule_name(str): The name of the monitoring schedule to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.monitoring.schedule.delete(
                ctx, monitoring_schedule_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.monitoring.schedule.delete monitoring_schedule_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="delete_monitoring_schedule",
        op_kwargs={"MonitoringScheduleName": monitoring_schedule_name},
    )


async def describe(hub, ctx, monitoring_schedule_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes the schedule for a monitoring job.

    Args:
        monitoring_schedule_name(str): Name of a previously created monitoring schedule.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.monitoring.schedule.describe(
                ctx, monitoring_schedule_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.monitoring.schedule.describe monitoring_schedule_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="describe_monitoring_schedule",
        op_kwargs={"MonitoringScheduleName": monitoring_schedule_name},
    )


async def list_all(
    hub,
    ctx,
    endpoint_name: str = None,
    sort_by: str = None,
    sort_order: str = None,
    next_token: str = None,
    max_results: int = None,
    name_contains: str = None,
    creation_time_before: str = None,
    creation_time_after: str = None,
    last_modified_time_before: str = None,
    last_modified_time_after: str = None,
    status_equals: str = None,
    monitoring_job_definition_name: str = None,
    monitoring_type_equals: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns list of all monitoring schedules.

    Args:
        endpoint_name(str, optional): Name of a specific endpoint to fetch schedules for. Defaults to None.
        sort_by(str, optional): Whether to sort results by Status, CreationTime, ScheduledTime field. The default is CreationTime. Defaults to None.
        sort_order(str, optional): Whether to sort the results in Ascending or Descending order. The default is Descending. Defaults to None.
        next_token(str, optional): The token returned if the response is truncated. To retrieve the next set of job executions, use it in the next request. Defaults to None.
        max_results(int, optional): The maximum number of jobs to return in the response. The default value is 10. Defaults to None.
        name_contains(str, optional): Filter for monitoring schedules whose name contains a specified string. Defaults to None.
        creation_time_before(str, optional): A filter that returns only monitoring schedules created before a specified time. Defaults to None.
        creation_time_after(str, optional): A filter that returns only monitoring schedules created after a specified time. Defaults to None.
        last_modified_time_before(str, optional): A filter that returns only monitoring schedules modified before a specified time. Defaults to None.
        last_modified_time_after(str, optional): A filter that returns only monitoring schedules modified after a specified time. Defaults to None.
        status_equals(str, optional): A filter that returns only monitoring schedules modified before a specified time. Defaults to None.
        monitoring_job_definition_name(str, optional): Gets a list of the monitoring schedules for the specified monitoring job definition. Defaults to None.
        monitoring_type_equals(str, optional): A filter that returns only the monitoring schedules for the specified monitoring type. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.monitoring.schedule.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.monitoring.schedule.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="list_monitoring_schedules",
        op_kwargs={
            "EndpointName": endpoint_name,
            "SortBy": sort_by,
            "SortOrder": sort_order,
            "NextToken": next_token,
            "MaxResults": max_results,
            "NameContains": name_contains,
            "CreationTimeBefore": creation_time_before,
            "CreationTimeAfter": creation_time_after,
            "LastModifiedTimeBefore": last_modified_time_before,
            "LastModifiedTimeAfter": last_modified_time_after,
            "StatusEquals": status_equals,
            "MonitoringJobDefinitionName": monitoring_job_definition_name,
            "MonitoringTypeEquals": monitoring_type_equals,
        },
    )


async def start(hub, ctx, monitoring_schedule_name: str) -> None:
    r"""
    **Autogenerated function**

    Starts a previously stopped monitoring schedule.  By default, when you successfully create a new schedule, the status of a monitoring schedule is scheduled.

    Args:
        monitoring_schedule_name(str): The name of the schedule to start.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.monitoring.schedule.start(
                ctx, monitoring_schedule_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.monitoring.schedule.start monitoring_schedule_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="start_monitoring_schedule",
        op_kwargs={"MonitoringScheduleName": monitoring_schedule_name},
    )


async def stop(hub, ctx, monitoring_schedule_name: str) -> None:
    r"""
    **Autogenerated function**

    Stops a previously started monitoring schedule.

    Args:
        monitoring_schedule_name(str): The name of the schedule to stop.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.monitoring.schedule.stop(
                ctx, monitoring_schedule_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.monitoring.schedule.stop monitoring_schedule_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="stop_monitoring_schedule",
        op_kwargs={"MonitoringScheduleName": monitoring_schedule_name},
    )


async def update(
    hub, ctx, monitoring_schedule_name: str, monitoring_schedule_config: Dict
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a previously created schedule.

    Args:
        monitoring_schedule_name(str): The name of the monitoring schedule. The name must be unique within an Amazon Web Services Region within an Amazon Web Services account.
        monitoring_schedule_config(Dict): The configuration object that specifies the monitoring schedule and defines the monitoring job.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.monitoring.schedule.update(
                ctx, monitoring_schedule_name=value, monitoring_schedule_config=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.monitoring.schedule.update monitoring_schedule_name=value, monitoring_schedule_config=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="update_monitoring_schedule",
        op_kwargs={
            "MonitoringScheduleName": monitoring_schedule_name,
            "MonitoringScheduleConfig": monitoring_schedule_config,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__sub_alias__ = ["type_", "type"]


async def describe_all(
    hub,
    ctx,
    dry_run: bool = None,
    instance_types: List = None,
    filters: List = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the details of the instance types that are offered in a location. The results can be filtered by the attributes of the instance types.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        instance_types(List, optional): The instance types. For more information, see Instance types in the Amazon EC2 User Guide. Defaults to None.
        filters(List, optional): One or more filters. Filter names and values are case-sensitive.    auto-recovery-supported - Indicates whether auto recovery is supported (true | false).    bare-metal - Indicates whether it is a bare metal instance type (true | false).    burstable-performance-supported - Indicates whether it is a burstable performance instance type (true | false).    current-generation - Indicates whether this instance type is the latest generation instance type of an instance family (true | false).    ebs-info.ebs-optimized-info.baseline-bandwidth-in-mbps - The baseline bandwidth performance for an EBS-optimized instance type, in Mbps.    ebs-info.ebs-optimized-info.baseline-iops - The baseline input/output storage operations per second for an EBS-optimized instance type.    ebs-info.ebs-optimized-info.baseline-throughput-in-mbps - The baseline throughput performance for an EBS-optimized instance type, in MB/s.    ebs-info.ebs-optimized-info.maximum-bandwidth-in-mbps - The maximum bandwidth performance for an EBS-optimized instance type, in Mbps.    ebs-info.ebs-optimized-info.maximum-iops - The maximum input/output storage operations per second for an EBS-optimized instance type.    ebs-info.ebs-optimized-info.maximum-throughput-in-mbps - The maximum throughput performance for an EBS-optimized instance type, in MB/s.    ebs-info.ebs-optimized-support - Indicates whether the instance type is EBS-optimized (supported | unsupported | default).    ebs-info.encryption-support - Indicates whether EBS encryption is supported (supported | unsupported).    ebs-info.nvme-support - Indicates whether non-volatile memory express (NVMe) is supported for EBS volumes (required | supported | unsupported).    free-tier-eligible - Indicates whether the instance type is eligible to use in the free tier (true | false).    hibernation-supported - Indicates whether On-Demand hibernation is supported (true | false).    hypervisor - The hypervisor (nitro | xen).    instance-storage-info.disk.count - The number of local disks.    instance-storage-info.disk.size-in-gb - The storage size of each instance storage disk, in GB.    instance-storage-info.disk.type - The storage technology for the local instance storage disks (hdd | ssd).    instance-storage-info.nvme-support - Indicates whether non-volatile memory express (NVMe) is supported for instance store (required | supported) | unsupported).    instance-storage-info.total-size-in-gb - The total amount of storage available from all local instance storage, in GB.    instance-storage-supported - Indicates whether the instance type has local instance storage (true | false).    instance-type - The instance type (for example c5.2xlarge or c5*).    memory-info.size-in-mib - The memory size.    network-info.efa-info.maximum-efa-interfaces - The maximum number of Elastic Fabric Adapters (EFAs) per instance.    network-info.efa-supported - Indicates whether the instance type supports Elastic Fabric Adapter (EFA) (true | false).    network-info.ena-support - Indicates whether Elastic Network Adapter (ENA) is supported or required (required | supported | unsupported).    network-info.ipv4-addresses-per-interface - The maximum number of private IPv4 addresses per network interface.    network-info.ipv6-addresses-per-interface - The maximum number of private IPv6 addresses per network interface.    network-info.ipv6-supported - Indicates whether the instance type supports IPv6 (true | false).    network-info.maximum-network-interfaces - The maximum number of network interfaces per instance.    network-info.network-performance - The network performance (for example, "25 Gigabit").    processor-info.supported-architecture - The CPU architecture (arm64 | i386 | x86_64).    processor-info.sustained-clock-speed-in-ghz - The CPU clock speed, in GHz.    supported-boot-mode - The boot mode (legacy-bios | uefi).    supported-root-device-type - The root device type (ebs | instance-store).    supported-usage-class - The usage class (on-demand | spot).    supported-virtualization-type - The virtualization type (hvm | paravirtual).    vcpu-info.default-cores - The default number of cores for the instance type.    vcpu-info.default-threads-per-core - The default number of threads per core for the instance type.    vcpu-info.default-vcpus - The default number of vCPUs for the instance type.    vcpu-info.valid-cores - The number of cores that can be configured for the instance type.    vcpu-info.valid-threads-per-core - The number of threads per core that can be configured for the instance type. For example, "1" or "1,2".  . Defaults to None.
        max_results(int, optional): The maximum number of results to return for the request in a single page. The remaining results can be seen by sending another request with the next token value. Defaults to None.
        next_token(str, optional): The token to retrieve the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.instance.type_.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.instance.type_.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_instance_types",
        op_kwargs={
            "DryRun": dry_run,
            "InstanceTypes": instance_types,
            "Filters": filters,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def apply(
    hub, ctx, analyzer_arn: str, rule_name: str, client_token: str = None
) -> None:
    r"""
    **Autogenerated function**

    Retroactively applies the archive rule to existing findings that meet the archive rule criteria.

    Args:
        analyzer_arn(str): The Amazon resource name (ARN) of the analyzer.
        client_token(str, optional): A client token. Defaults to None.
        rule_name(str): The name of the rule to apply.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.accessanalyzer.archive_rule.apply(
                ctx, analyzer_arn=value, rule_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.accessanalyzer.archive_rule.apply analyzer_arn=value, rule_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="accessanalyzer",
        operation="apply_archive_rule",
        op_kwargs={
            "analyzerArn": analyzer_arn,
            "clientToken": client_token,
            "ruleName": rule_name,
        },
    )


async def create(
    hub,
    ctx,
    analyzer_name: str,
    filter_: Dict,
    rule_name: str,
    client_token: str = None,
) -> None:
    r"""
    **Autogenerated function**

    Creates an archive rule for the specified analyzer. Archive rules automatically archive new findings that meet the criteria you define when you create the rule. To learn about filter keys that you can use to create an archive rule, see Access Analyzer filter keys in the IAM User Guide.

    Args:
        analyzer_name(str): The name of the created analyzer.
        client_token(str, optional): A client token. Defaults to None.
        filter_(Dict): The criteria for the rule.
        rule_name(str): The name of the rule to create.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.accessanalyzer.archive_rule.create(
                ctx, analyzer_name=value, filter_=value, rule_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.accessanalyzer.archive_rule.create analyzer_name=value, filter_=value, rule_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="accessanalyzer",
        operation="create_archive_rule",
        op_kwargs={
            "analyzerName": analyzer_name,
            "clientToken": client_token,
            "filter": filter_,
            "ruleName": rule_name,
        },
    )


async def delete(
    hub, ctx, analyzer_name: str, rule_name: str, client_token: str = None
) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified archive rule.

    Args:
        analyzer_name(str): The name of the analyzer that associated with the archive rule to delete.
        client_token(str, optional): A client token. Defaults to None.
        rule_name(str): The name of the rule to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.accessanalyzer.archive_rule.delete(
                ctx, analyzer_name=value, rule_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.accessanalyzer.archive_rule.delete analyzer_name=value, rule_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="accessanalyzer",
        operation="delete_archive_rule",
        op_kwargs={
            "analyzerName": analyzer_name,
            "clientToken": client_token,
            "ruleName": rule_name,
        },
    )


async def get(hub, ctx, analyzer_name: str, rule_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about an archive rule. To learn about filter keys that you can use to create an archive rule, see Access Analyzer filter keys in the IAM User Guide.

    Args:
        analyzer_name(str): The name of the analyzer to retrieve rules from.
        rule_name(str): The name of the rule to retrieve.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.accessanalyzer.archive_rule.get(
                ctx, analyzer_name=value, rule_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.accessanalyzer.archive_rule.get analyzer_name=value, rule_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="accessanalyzer",
        operation="get_archive_rule",
        op_kwargs={"analyzerName": analyzer_name, "ruleName": rule_name},
    )


async def list_all(
    hub, ctx, analyzer_name: str, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a list of archive rules created for the specified analyzer.

    Args:
        analyzer_name(str): The name of the analyzer to retrieve rules from.
        max_results(int, optional): The maximum number of results to return in the request. Defaults to None.
        next_token(str, optional): A token used for pagination of results returned. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.accessanalyzer.archive_rule.list_all(ctx, analyzer_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.accessanalyzer.archive_rule.list_all analyzer_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="accessanalyzer",
        operation="list_archive_rules",
        op_kwargs={
            "analyzerName": analyzer_name,
            "maxResults": max_results,
            "nextToken": next_token,
        },
    )


async def update(
    hub,
    ctx,
    analyzer_name: str,
    filter_: Dict,
    rule_name: str,
    client_token: str = None,
) -> None:
    r"""
    **Autogenerated function**

    Updates the criteria and values for the specified archive rule.

    Args:
        analyzer_name(str): The name of the analyzer to update the archive rules for.
        client_token(str, optional): A client token. Defaults to None.
        filter_(Dict): A filter to match for the rules to update. Only rules that match the filter are updated.
        rule_name(str): The name of the rule to update.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.accessanalyzer.archive_rule.update(
                ctx, analyzer_name=value, filter_=value, rule_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.accessanalyzer.archive_rule.update analyzer_name=value, filter_=value, rule_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="accessanalyzer",
        operation="update_archive_rule",
        op_kwargs={
            "analyzerName": analyzer_name,
            "clientToken": client_token,
            "filter": filter_,
            "ruleName": rule_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(
    hub, ctx, project_name: str, sort_order: str = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets a list of build identifiers for the specified build project, with each build identifier representing a single build.

    Args:
        project_name(str): The name of the AWS CodeBuild project.
        sort_order(str, optional): The order to list results in. The results are sorted by build number, not the build identifier. Valid values include:    ASCENDING: List the build IDs in ascending order by build ID.    DESCENDING: List the build IDs in descending order by build ID.   If the project has more than 100 builds, setting the sort order will result in an error. . Defaults to None.
        next_token(str, optional): During a previous call, if there are more than 100 items in the list, only the first 100 items are returned, along with a unique string called a nextToken. To get the next batch of items in the list, call this operation again, adding the next token to the call. To get all of the items in the list, keep calling this operation with each subsequent next token that is returned, until no more next tokens are returned. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codebuild.build.for_project.list(ctx, project_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codebuild.build.for_project.list project_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codebuild",
        operation="list_builds_for_project",
        op_kwargs={
            "projectName": project_name,
            "sortOrder": sort_order,
            "nextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(
    hub,
    ctx,
    reserved_elasticsearch_instance_id: str = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about reserved Elasticsearch instances for this account.

    Args:
        reserved_elasticsearch_instance_id(str, optional): The reserved instance identifier filter value. Use this parameter to show only the reservation that matches the specified reserved Elasticsearch instance ID. Defaults to None.
        max_results(int, optional): Set this value to limit the number of results returned. If not specified, defaults to 100. Defaults to None.
        next_token(str, optional): NextToken should be sent in case if earlier API call produced result containing NextToken. It is used for pagination. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.es.reserved_elasticsearch_instance.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.es.reserved_elasticsearch_instance.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="es",
        operation="describe_reserved_elasticsearch_instances",
        op_kwargs={
            "ReservedElasticsearchInstanceId": reserved_elasticsearch_instance_id,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def create(
    hub,
    ctx,
    name: str,
    parallel_data_config: Dict,
    client_token: str,
    description: str = None,
    encryption_key: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a parallel data resource in Amazon Translate by importing an input file from Amazon S3. Parallel data files contain examples of source phrases and their translations from your translation memory. By adding parallel data, you can influence the style, tone, and word choice in your translation output.

    Args:
        name(str): A custom name for the parallel data resource in Amazon Translate. You must assign a name that is unique in the account and region.
        description(str, optional): A custom description for the parallel data resource in Amazon Translate. Defaults to None.
        parallel_data_config(Dict): Specifies the format and S3 location of the parallel data input file.
        encryption_key(Dict, optional): The encryption key used to encrypt this object. Defaults to None.
        client_token(str): A unique identifier for the request. This token is automatically generated when you use Amazon Translate through an AWS SDK.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.translate.parallel_data.create(
                ctx, name=value, parallel_data_config=value, client_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.translate.parallel_data.create name=value, parallel_data_config=value, client_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="translate",
        operation="create_parallel_data",
        op_kwargs={
            "Name": name,
            "Description": description,
            "ParallelDataConfig": parallel_data_config,
            "EncryptionKey": encryption_key,
            "ClientToken": client_token,
        },
    )


async def delete(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a parallel data resource in Amazon Translate.

    Args:
        name(str): The name of the parallel data resource that is being deleted.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.translate.parallel_data.delete(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.translate.parallel_data.delete name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="translate",
        operation="delete_parallel_data",
        op_kwargs={"Name": name},
    )


async def get(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Provides information about a parallel data resource.

    Args:
        name(str): The name of the parallel data resource that is being retrieved.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.translate.parallel_data.get(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.translate.parallel_data.get name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="translate",
        operation="get_parallel_data",
        op_kwargs={"Name": name},
    )


async def list_(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Provides a list of your parallel data resources in Amazon Translate.

    Args:
        next_token(str, optional): A string that specifies the next page of results to return in a paginated response. Defaults to None.
        max_results(int, optional): The maximum number of parallel data resources returned for each request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.translate.parallel_data.list(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.translate.parallel_data.list
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="translate",
        operation="list_parallel_data",
        op_kwargs={"NextToken": next_token, "MaxResults": max_results},
    )


async def update(
    hub,
    ctx,
    name: str,
    parallel_data_config: Dict,
    client_token: str,
    description: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a previously created parallel data resource by importing a new input file from Amazon S3.

    Args:
        name(str): The name of the parallel data resource being updated.
        description(str, optional): A custom description for the parallel data resource in Amazon Translate. Defaults to None.
        parallel_data_config(Dict): Specifies the format and S3 location of the parallel data input file.
        client_token(str): A unique identifier for the request. This token is automatically generated when you use Amazon Translate through an AWS SDK.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.translate.parallel_data.update(
                ctx, name=value, parallel_data_config=value, client_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.translate.parallel_data.update name=value, parallel_data_config=value, client_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="translate",
        operation="update_parallel_data",
        op_kwargs={
            "Name": name,
            "Description": description,
            "ParallelDataConfig": parallel_data_config,
            "ClientToken": client_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def upload(hub, ctx, documents: bytes, content_type: str) -> Dict:
    r"""
    **Autogenerated function**

    Posts a batch of documents to a search domain for indexing. A document batch is a collection of add and delete operations that represent the documents you want to add, update, or delete from your domain. Batches can be described in either JSON or XML. Each item that you want Amazon CloudSearch to return as a search result (such as a product) is represented as a document. Every document has a unique ID and one or more fields that contain the data that you want to search and return in results. Individual documents cannot contain more than 1 MB of data. The entire batch cannot exceed 5 MB. To get the best possible upload performance, group add and delete operations in batches that are close the 5 MB limit. Submitting a large volume of single-document batches can overload a domain's document service.  The endpoint for submitting UploadDocuments requests is domain-specific. To get the document endpoint for your domain, use the Amazon CloudSearch configuration service DescribeDomains action. A domain's endpoints are also displayed on the domain dashboard in the Amazon CloudSearch console.  For more information about formatting your data for Amazon CloudSearch, see Preparing Your Data in the Amazon CloudSearch Developer Guide. For more information about uploading data for indexing, see Uploading Data in the Amazon CloudSearch Developer Guide.

    Args:
        documents(bytes): A batch of documents formatted in JSON or HTML.
        content_type(str): The format of the batch you are uploading. Amazon CloudSearch supports two document batch formats:  application/json application/xml .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudsearchdomain.document.upload(
                ctx, documents=value, content_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudsearchdomain.document.upload documents=value, content_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudsearchdomain",
        operation="upload_documents",
        op_kwargs={"documents": documents, "contentType": content_type},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def list_all(
    hub, ctx, studio_id: str, eula_ids: List = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    List Eula Acceptances.

    Args:
        eula_ids(List, optional): A collection of EULA IDs. Defaults to None.
        next_token(str, optional): The token for the next set of results, or null if there are no more results. Defaults to None.
        studio_id(str): The studio ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.nimble.eula.acceptance.list_all(ctx, studio_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.nimble.eula.acceptance.list_all studio_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="nimble",
        operation="list_eula_acceptances",
        op_kwargs={"eulaIds": eula_ids, "nextToken": next_token, "studioId": studio_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def analyze(hub, ctx, document: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Analyzes an input document for financially related relationships between text. Information is returned as ExpenseDocuments and seperated as follows.    LineItemGroups- A data set containing LineItems which store information about the lines of text, such as an item purchased and its price on a receipt.    SummaryFields- Contains all other information a receipt, such as header information or the vendors name.

    Args:
        document(Dict): The input document, either as bytes or as an S3 object. You pass image bytes to an Amazon Textract API operation by using the Bytes property. For example, you would use the Bytes property to pass a document loaded from a local file system. Image bytes passed by using the Bytes property must be base64 encoded. Your code might not need to encode document file bytes if you're using an AWS SDK to call Amazon Textract API operations.  You pass images stored in an S3 bucket to an Amazon Textract API operation by using the S3Object property. Documents stored in an S3 bucket don't need to be base64 encoded. The AWS Region for the S3 bucket that contains the S3 object must match the AWS Region that you use for Amazon Textract operations. If you use the AWS CLI to call Amazon Textract operations, passing image bytes using the Bytes property isn't supported. You must first upload the document to an Amazon S3 bucket, and then call the operation using the S3Object property. For Amazon Textract to process an S3 object, the user must have permission to access the S3 object. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.textract.expense.analyze(ctx, document=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.textract.expense.analyze document=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="textract",
        operation="analyze_expense",
        op_kwargs={"Document": document},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub,
    ctx,
    resource_type: str,
    resource_id: str,
    later_time: str = None,
    earlier_time: str = None,
    chronological_order: str = None,
    limit: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of configuration items for the specified resource. The list contains details about each state of the resource during the specified time interval. If you specified a retention period to retain your ConfigurationItems between a minimum of 30 days and a maximum of 7 years (2557 days), AWS Config returns the ConfigurationItems for the specified retention period.  The response is paginated. By default, AWS Config returns a limit of 10 configuration items per page. You can customize this number with the limit parameter. The response includes a nextToken string. To get the next page of results, run the request again and specify the string for the nextToken parameter.  Each call to the API is limited to span a duration of seven days. It is likely that the number of records returned is smaller than the specified limit. In such cases, you can make another call, using the nextToken.

    Args:
        resource_type(str): The resource type.
        resource_id(str): The ID of the resource (for example., sg-xxxxxx).
        later_time(str, optional): The time stamp that indicates a later time. If not specified, current time is taken. Defaults to None.
        earlier_time(str, optional): The time stamp that indicates an earlier time. If not specified, the action returns paginated results that contain configuration items that start when the first configuration item was recorded. Defaults to None.
        chronological_order(str, optional): The chronological order for configuration items listed. By default, the results are listed in reverse chronological order. Defaults to None.
        limit(int, optional): The maximum number of configuration items returned on each page. The default is 10. You cannot specify a number greater than 100. If you specify 0, AWS Config uses the default. Defaults to None.
        next_token(str, optional): The nextToken string returned on a previous page that you use to get the next page of results in a paginated response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.config.resource.config.history.get(
                ctx, resource_type=value, resource_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.config.resource.config.history.get resource_type=value, resource_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="config",
        operation="get_resource_config_history",
        op_kwargs={
            "resourceType": resource_type,
            "resourceId": resource_id,
            "laterTime": later_time,
            "earlierTime": earlier_time,
            "chronologicalOrder": chronological_order,
            "limit": limit,
            "nextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub,
    ctx,
    stack_id: str = None,
    instance_id: str = None,
    service_error_ids: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes AWS OpsWorks Stacks service errors.  Required Permissions: To use this action, an IAM user must have a Show, Deploy, or Manage permissions level for the stack, or an attached policy that explicitly grants permissions. For more information about user permissions, see Managing User Permissions. This call accepts only one resource-identifying parameter.

    Args:
        stack_id(str, optional): The stack ID. If you use this parameter, DescribeServiceErrors returns descriptions of the errors associated with the specified stack. Defaults to None.
        instance_id(str, optional): The instance ID. If you use this parameter, DescribeServiceErrors returns descriptions of the errors associated with the specified instance. Defaults to None.
        service_error_ids(List, optional): An array of service error IDs. If you use this parameter, DescribeServiceErrors returns descriptions of the specified errors. Otherwise, it returns a description of every error. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opswork.service_error.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opswork.service_error.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworks",
        operation="describe_service_errors",
        op_kwargs={
            "StackId": stack_id,
            "InstanceId": instance_id,
            "ServiceErrorIds": service_error_ids,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def allocate(
    hub,
    ctx,
    bandwidth: str,
    connection_name: str,
    owner_account: str,
    interconnect_id: str,
    vlan: int,
) -> Dict:
    r"""
    **Autogenerated function**

    Deprecated. Use AllocateHostedConnection instead. Creates a hosted connection on an interconnect. Allocates a VLAN number and a specified amount of bandwidth for use by a hosted connection on the specified interconnect.  Intended for use by Direct Connect Partners only.

    Args:
        bandwidth(str): The bandwidth of the connection. The possible values are 50Mbps, 100Mbps, 200Mbps, 300Mbps, 400Mbps, 500Mbps, 1Gbps, 2Gbps, 5Gbps, and 10Gbps. Note that only those Direct Connect Partners who have met specific requirements are allowed to create a 1Gbps, 2Gbps, 5Gbps or 10Gbps hosted connection.
        connection_name(str): The name of the provisioned connection.
        owner_account(str): The ID of the account of the customer for whom the connection will be provisioned.
        interconnect_id(str): The ID of the interconnect on which the connection will be provisioned.
        vlan(int): The dedicated VLAN provisioned to the connection.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.directconnect.connection.on_interconnect.allocate(
                ctx,
                bandwidth=value,
                connection_name=value,
                owner_account=value,
                interconnect_id=value,
                vlan=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.directconnect.connection.on_interconnect.allocate bandwidth=value, connection_name=value, owner_account=value, interconnect_id=value, vlan=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="directconnect",
        operation="allocate_connection_on_interconnect",
        op_kwargs={
            "bandwidth": bandwidth,
            "connectionName": connection_name,
            "ownerAccount": owner_account,
            "interconnectId": interconnect_id,
            "vlan": vlan,
        },
    )


async def describe(hub, ctx, interconnect_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deprecated. Use DescribeHostedConnections instead. Lists the connections that have been provisioned on the specified interconnect.  Intended for use by Direct Connect Partners only.

    Args:
        interconnect_id(str): The ID of the interconnect.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.directconnect.connection.on_interconnect.describe(
                ctx, interconnect_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.directconnect.connection.on_interconnect.describe interconnect_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="directconnect",
        operation="describe_connections_on_interconnect",
        op_kwargs={"interconnectId": interconnect_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, app_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves output from validating an application.

    Args:
        app_id(str): The ID of the application.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sms.app.validation.output.get(ctx, app_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sms.app.validation.output.get app_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sms",
        operation="get_app_validation_output",
        op_kwargs={"appId": app_id},
    )


async def notify(hub, ctx, app_id: str, notification_context: Dict = None) -> Dict:
    r"""
    **Autogenerated function**

    Provides information to AWS SMS about whether application validation is successful.

    Args:
        app_id(str): The ID of the application.
        notification_context(Dict, optional): The notification information. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sms.app.validation.output.notify(ctx, app_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sms.app.validation.output.notify app_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sms",
        operation="notify_app_validation_output",
        op_kwargs={"appId": app_id, "notificationContext": notification_context},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def merge(
    hub,
    ctx,
    repository_name: str,
    source_commit_specifier: str,
    destination_commit_specifier: str,
    target_branch: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Merges two branches using the fast-forward merge strategy.

    Args:
        repository_name(str): The name of the repository where you want to merge two branches.
        source_commit_specifier(str): The branch, tag, HEAD, or other fully qualified reference used to identify a commit (for example, a branch name or a full commit ID).
        destination_commit_specifier(str): The branch, tag, HEAD, or other fully qualified reference used to identify a commit (for example, a branch name or a full commit ID).
        target_branch(str, optional): The branch where the merge is applied. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codecommit.branch.by.fast_forward.merge(
                ctx,
                repository_name=value,
                source_commit_specifier=value,
                destination_commit_specifier=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codecommit.branch.by.fast_forward.merge repository_name=value, source_commit_specifier=value, destination_commit_specifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codecommit",
        operation="merge_branches_by_fast_forward",
        op_kwargs={
            "repositoryName": repository_name,
            "sourceCommitSpecifier": source_commit_specifier,
            "destinationCommitSpecifier": destination_commit_specifier,
            "targetBranch": target_branch,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get(hub, ctx, name: str, run_id: str, include_graph: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the metadata for a given workflow run.

    Args:
        name(str): Name of the workflow being run.
        run_id(str): The ID of the workflow run.
        include_graph(bool, optional): Specifies whether to include the workflow graph in response or not. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.workflow.run.init.get(ctx, name=value, run_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.workflow.run.init.get name=value, run_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="get_workflow_run",
        op_kwargs={"Name": name, "RunId": run_id, "IncludeGraph": include_graph},
    )


async def get_all(
    hub,
    ctx,
    name: str,
    include_graph: bool = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves metadata for all runs of a given workflow.

    Args:
        name(str): Name of the workflow whose metadata of runs should be returned.
        include_graph(bool, optional): Specifies whether to include the workflow graph in response or not. Defaults to None.
        next_token(str, optional): The maximum size of the response. Defaults to None.
        max_results(int, optional): The maximum number of workflow runs to be included in the response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.workflow.run.init.get_all(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.workflow.run.init.get_all name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="get_workflow_runs",
        op_kwargs={
            "Name": name,
            "IncludeGraph": include_graph,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def resume(hub, ctx, name: str, run_id: str, node_ids: List) -> Dict:
    r"""
    **Autogenerated function**

    Restarts selected nodes of a previous partially completed workflow run and resumes the workflow run. The selected nodes and all nodes that are downstream from the selected nodes are run.

    Args:
        name(str): The name of the workflow to resume.
        run_id(str): The ID of the workflow run to resume.
        node_ids(List): A list of the node IDs for the nodes you want to restart. The nodes that are to be restarted must have a run attempt in the original run.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.workflow.run.init.resume(
                ctx, name=value, run_id=value, node_ids=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.workflow.run.init.resume name=value, run_id=value, node_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="resume_workflow_run",
        op_kwargs={"Name": name, "RunId": run_id, "NodeIds": node_ids},
    )


async def start(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Starts a new run of the specified workflow.

    Args:
        name(str): The name of the workflow to start.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.workflow.run.init.start(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.workflow.run.init.start name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="start_workflow_run",
        op_kwargs={"Name": name},
    )


async def stop(hub, ctx, name: str, run_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Stops the execution of the specified workflow run.

    Args:
        name(str): The name of the workflow to stop.
        run_id(str): The ID of the workflow run to stop.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.workflow.run.init.stop(ctx, name=value, run_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.workflow.run.init.stop name=value, run_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="stop_workflow_run",
        op_kwargs={"Name": name, "RunId": run_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub, ctx, channel_name: str, outputs: List, playback_mode: str, tags: Dict = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a channel.

    Args:
        channel_name(str): The identifier for the channel you are working on.
        outputs(List): The channel's output properties.
        playback_mode(str): The type of playback mode for this channel. The only supported value is LOOP.
        tags(Dict, optional): The tags to assign to the channel. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediatailor.channel.init.create(
                ctx, channel_name=value, outputs=value, playback_mode=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediatailor.channel.init.create channel_name=value, outputs=value, playback_mode=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediatailor",
        operation="create_channel",
        op_kwargs={
            "ChannelName": channel_name,
            "Outputs": outputs,
            "PlaybackMode": playback_mode,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, channel_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a channel. You must stop the channel before it can be deleted.

    Args:
        channel_name(str): The identifier for the channel you are working on.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediatailor.channel.init.delete(ctx, channel_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediatailor.channel.init.delete channel_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediatailor",
        operation="delete_channel",
        op_kwargs={"ChannelName": channel_name},
    )


async def describe(hub, ctx, channel_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes the properties of a specific channel.

    Args:
        channel_name(str): The identifier for the channel you are working on.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediatailor.channel.init.describe(ctx, channel_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediatailor.channel.init.describe channel_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediatailor",
        operation="describe_channel",
        op_kwargs={"ChannelName": channel_name},
    )


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a list of channels that are associated with this account.

    Args:
        max_results(int, optional): Upper bound on number of records to return. The maximum number of results is 100. Defaults to None.
        next_token(str, optional): Pagination token from the GET list request. Use the token to fetch the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediatailor.channel.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediatailor.channel.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediatailor",
        operation="list_channels",
        op_kwargs={"MaxResults": max_results, "NextToken": next_token},
    )


async def start(hub, ctx, channel_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Starts a specific channel.

    Args:
        channel_name(str): The identifier for the channel you are working on.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediatailor.channel.init.start(ctx, channel_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediatailor.channel.init.start channel_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediatailor",
        operation="start_channel",
        op_kwargs={"ChannelName": channel_name},
    )


async def stop(hub, ctx, channel_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Stops a specific channel.

    Args:
        channel_name(str): The identifier for the channel you are working on.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediatailor.channel.init.stop(ctx, channel_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediatailor.channel.init.stop channel_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediatailor",
        operation="stop_channel",
        op_kwargs={"ChannelName": channel_name},
    )


async def update(hub, ctx, channel_name: str, outputs: List) -> Dict:
    r"""
    **Autogenerated function**

    Updates an existing channel.

    Args:
        channel_name(str): The identifier for the channel you are working on.
        outputs(List): The channel's output properties.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediatailor.channel.init.update(
                ctx, channel_name=value, outputs=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediatailor.channel.init.update channel_name=value, outputs=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediatailor",
        operation="update_channel",
        op_kwargs={"ChannelName": channel_name, "Outputs": outputs},
    )
